@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,19 +66,88 @@ import java.util.ListResourceBundle;
 public class FormatData_en_BE extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String metaValue_generic_DateFormatItem_yMEd = "E, d/M/y";
+        final String metaValue_generic_DateFormatItem_Md = "d/M";
+        final String metaValue_generic_DateFormatItem_MEd = "E, d/M";
+        final String metaValue_generic_DateFormatItem_yMd = "d/M/y";
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "",
-               "",
-               "dd MMM y G",
-               "",
-            };
+            "",
+            "",
+            "dd MMM y G",
+            "",
+        };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "",
-               "",
-               "dd MMM y GGGG",
-               "",
-            };
+            "",
+            "",
+            "dd MMM y GGGG",
+            "",
+        };
         final Object[][] data = new Object[][] {
+            { "generic.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y GGGG",
+                    "d MMMM y GGGG",
+                    "dd MMM y GGGG",
+                    "dd/MM/y G",
+                }
+            },
+            { "roc.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-umalqura.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "java.time.japanese.DatePatterns",
+                new String[] {
+                    "EEEE, MMMM d, y G",
+                    "MMMM d, y G",
+                    "dd MMM y G",
+                    "M/d/y GGGGG",
+                }
+            },
+            { "islamic-civil.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "buddhist.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "generic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "islamic-umalqura.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "buddhist.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "roc.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "generic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "roc.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "buddhist.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
+            { "japanese.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "japanese.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic-umalqura.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "generic.DateFormatItem.yyyyMd", "d/M/y G" },
+            { "islamic-civil.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "islamic-civil.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "generic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "generic.DateFormatItem.yyyyMEd", "E, d/M/y G" },
+            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "islamic.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
+            { "japanese.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "islamic.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "dd MMM y",
+                    "dd/MM/yy",
+                }
+            },
+            { "java.time.generic.DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y G",
+                    "d MMMM y G",
+                    "dd MMM y G",
+                    "dd/MM/y GGGGG",
+                }
+            },
+            { "generic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
+            { "islamic.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -100,6 +165,9 @@ public class FormatData_en_BE extends ListResourceBundle {
                     "",
                 }
             },
+            { "roc.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
             { "japanese.DatePatterns",
                 new String[] {
                     "EEEE, MMMM d, y GGGG",
@@ -108,17 +176,9 @@ public class FormatData_en_BE extends ListResourceBundle {
                     "M/d/y G",
                 }
             },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.japanese.DatePatterns",
-                new String[] {
-                    "EEEE, MMMM d, y G",
-                    "MMMM d, y G",
-                    "dd MMM y G",
-                    "M/d/y GGGGG",
-                }
-            },
+            { "japanese.DateFormatItem.MEd", metaValue_generic_DateFormatItem_MEd },
+            { "islamic-civil.DateFormatItem.yMEd", metaValue_generic_DateFormatItem_yMEd },
+            { "buddhist.DateFormatItem.yMd", metaValue_generic_DateFormatItem_yMd },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -127,17 +187,7 @@ public class FormatData_en_BE extends ListResourceBundle {
                     "#,##0.00\u00a0\u00a4",
                 }
             },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "DatePatterns",
-                new String[] {
-                    "EEEE, d MMMM y",
-                    "d MMMM y",
-                    "dd MMM y",
-                    "dd/MM/yy",
-                }
-            },
+            { "islamic-umalqura.DateFormatItem.Md", metaValue_generic_DateFormatItem_Md },
         };
         return data;
     }
