@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,39 +66,48 @@ import java.util.ListResourceBundle;
 public class FormatData_es_HN extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_AmPmMarkers = new String[] {
-               "a.\u00a0m.",
-               "p.\u00a0m.",
-            };
         final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE dd 'de' MMMM 'de' y G",
-               "dd 'de' MMMM 'de' y G",
-               "",
-               "",
-            };
+            "EEEE dd 'de' MMMM 'de' y G",
+            "dd 'de' MMMM 'de' y G",
+            "",
+            "",
+        };
         final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE dd 'de' MMMM 'de' y GGGG",
-               "dd 'de' MMMM 'de' y GGGG",
-               "",
-               "",
-            };
+            "EEEE dd 'de' MMMM 'de' y GGGG",
+            "dd 'de' MMMM 'de' y GGGG",
+            "",
+            "",
+        };
         final Object[][] data = new Object[][] {
-            { "japanese.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.AmPmMarkers", metaValue_AmPmMarkers },
-            { "islamic.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "AmPmMarkers", metaValue_AmPmMarkers },
+            { "generic.DatePatterns",
+                new String[] {
+                    "EEEE dd 'de' MMMM 'de' y GGGG",
+                    "dd 'de' MMMM 'de' y GGGG",
+                    "d 'de' MMM 'de' y GGGG",
+                    "d/M/y G",
+                }
+            },
+            { "japanese.DatePatterns",
+                new String[] {
+                    "EEEE dd 'de' MMMM 'de' y GGGG",
+                    "dd 'de' MMMM 'de' y GGGG",
+                    "dd/MM/y G",
+                    "dd/MM/yy G",
+                }
+            },
+            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.japanese.DatePatterns",
                 new String[] {
                     "EEEE dd 'de' MMMM 'de' y G",
                     "dd 'de' MMMM 'de' y G",
-                    "dd/MM/y G",
+                    "dd/MM/y GGGGG",
                     "dd/MM/yy GGGGG",
                 }
             },
             { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
             { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
             { "DatePatterns",
                 new String[] {
@@ -112,21 +117,14 @@ public class FormatData_es_HN extends ListResourceBundle {
                     "d/M/yy",
                 }
             },
-            { "japanese.DatePatterns",
+            { "java.time.generic.DatePatterns",
                 new String[] {
-                    "EEEE dd 'de' MMMM 'de' y GGGG",
-                    "dd 'de' MMMM 'de' y GGGG",
-                    "dd/MM/y GGGG",
-                    "dd/MM/yy G",
+                    "EEEE dd 'de' MMMM 'de' y G",
+                    "dd 'de' MMMM 'de' y G",
+                    "d 'de' MMM 'de' y G",
+                    "d/M/y GGGGG",
                 }
             },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "buddhist.AmPmMarkers", metaValue_AmPmMarkers },
-            { "japanese.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
-            { "roc.abbreviated.AmPmMarkers", metaValue_AmPmMarkers },
         };
         return data;
     }
