@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,63 +66,63 @@ import java.util.ListResourceBundle;
 public class FormatData_kl extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
+        final String[] metaValue_generic_DayNames = new String[] {
+            "sapaat",
+            "ataasinngorneq",
+            "marlunngorneq",
+            "pingasunngorneq",
+            "sisamanngorneq",
+            "tallimanngorneq",
+            "arfininngorneq",
+        };
+        final String[] metaValue_generic_DayAbbreviations = new String[] {
+            "sap",
+            "ata",
+            "mar",
+            "pin",
+            "sis",
+            "tal",
+            "arf",
+        };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "HH.mm.ss zzzz",
+            "HH.mm.ss z",
+            "HH.mm.ss",
+            "HH.mm",
+        };
         final String[] metaValue_MonthNames = new String[] {
-               "januaarip",
-               "februaarip",
-               "marsip",
-               "apriilip",
-               "maajip",
-               "juunip",
-               "juulip",
-               "aggustip",
-               "septembarip",
-               "oktobarip",
-               "novembarip",
-               "decembarip",
-               "",
-            };
+            "januaarip",
+            "februaarip",
+            "marsip",
+            "apriilip",
+            "maajip",
+            "juunip",
+            "juulip",
+            "aggustip",
+            "septembarip",
+            "oktobarip",
+            "novembarip",
+            "decembarip",
+            "",
+        };
         final String[] metaValue_MonthAbbreviations = new String[] {
-               "jan",
-               "febr",
-               "mar",
-               "apr",
-               "maj",
-               "jun",
-               "jul",
-               "aug",
-               "sept",
-               "okt",
-               "nov",
-               "dec",
-               "",
-            };
-        final String[] metaValue_DayNames = new String[] {
-               "sapaat",
-               "ataasinngorneq",
-               "marlunngorneq",
-               "pingasunngorneq",
-               "sisamanngorneq",
-               "tallimanngorneq",
-               "arfininngorneq",
-            };
-        final String[] metaValue_DayAbbreviations = new String[] {
-               "sap",
-               "ata",
-               "mar",
-               "pin",
-               "sis",
-               "tal",
-               "arf",
-            };
-        final String[] metaValue_TimePatterns = new String[] {
-               "HH.mm.ss zzzz",
-               "HH.mm.ss z",
-               "HH.mm.ss",
-               "HH.mm",
-            };
+            "jan",
+            "febr",
+            "mar",
+            "apr",
+            "maj",
+            "jun",
+            "jul",
+            "aug",
+            "sept",
+            "okt",
+            "nov",
+            "dec",
+            "",
+        };
         final Object[][] data = new Object[][] {
             { "MonthNames", metaValue_MonthNames },
-            { "roc.DayAbbreviations", metaValue_DayAbbreviations },
+            { "roc.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "arab.NumberElements",
                 new String[] {
                     "\u066b",
@@ -144,12 +140,12 @@ public class FormatData_kl extends ListResourceBundle {
                     "",
                 }
             },
-            { "TimePatterns", metaValue_TimePatterns },
-            { "japanese.DayNames", metaValue_DayNames },
-            { "japanese.DayAbbreviations", metaValue_DayAbbreviations },
-            { "DayNames", metaValue_DayNames },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "japanese.DayNames", metaValue_generic_DayNames },
+            { "japanese.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "DayNames", metaValue_generic_DayNames },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
             { "roc.MonthNames", metaValue_MonthNames },
-            { "japanese.TimePatterns", metaValue_TimePatterns },
             { "arab.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -158,18 +154,20 @@ public class FormatData_kl extends ListResourceBundle {
                     "",
                 }
             },
-            { "DayAbbreviations", metaValue_DayAbbreviations },
+            { "DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "japanese.MonthNames", metaValue_MonthNames },
-            { "roc.DayNames", metaValue_DayNames },
-            { "standalone.DayAbbreviations", metaValue_DayAbbreviations },
+            { "roc.DayNames", metaValue_generic_DayNames },
+            { "standalone.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "roc.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayNames", metaValue_DayNames },
+            { "islamic.DayNames", metaValue_generic_DayNames },
+            { "buddhist.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "buddhist.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.DayAbbreviations", metaValue_DayAbbreviations },
-            { "islamic.TimePatterns", metaValue_TimePatterns },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "standalone.DayNames", metaValue_generic_DayNames },
             { "buddhist.MonthNames", metaValue_MonthNames },
             { "MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "standalone.DayNames", metaValue_DayNames },
+            { "PluralRules", "one:n = 1" },
             { "latn.NumberElements",
                 new String[] {
                     ",",
@@ -187,11 +185,13 @@ public class FormatData_kl extends ListResourceBundle {
                     "",
                 }
             },
+            { "buddhist.DayNames", metaValue_generic_DayNames },
+            { "generic.DayAbbreviations", metaValue_generic_DayAbbreviations },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
             { "japanese.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "buddhist.DayNames", metaValue_DayNames },
-            { "buddhist.TimePatterns", metaValue_TimePatterns },
+            { "generic.DayNames", metaValue_generic_DayNames },
+            { "islamic.DayAbbreviations", metaValue_generic_DayAbbreviations },
             { "standalone.MonthAbbreviations", metaValue_MonthAbbreviations },
-            { "islamic.DayAbbreviations", metaValue_DayAbbreviations },
             { "standalone.MonthNames",
                 new String[] {
                     "januaari",
@@ -217,7 +217,7 @@ public class FormatData_kl extends ListResourceBundle {
                     "",
                 }
             },
-            { "roc.TimePatterns", metaValue_TimePatterns },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
         };
         return data;
     }
