@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -104,6 +100,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
         final String metaValue_chr = "Cherokee";
         final String metaValue_cop = "Coptic";
         final String metaValue_got = "Gothic";
+        final String metaValue_kaw = "Kawi";
         final String metaValue_kpe = "Kpelle";
         final String metaValue_mak = "Makasar";
         final String metaValue_men = "Mende";
@@ -117,7 +114,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
         final String metaValue_uga = "Ugaritic";
         final String metaValue_vai = "Vai";
         final String metaValue_zbl = "Blissymbols";
-        final String metaValue_key_cu = "Currency";
         final Object[][] data = new Object[][] {
             { "ksh", "Colognian" },
             { "Ogam", "Ogham" },
@@ -125,7 +121,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Zsym", "Symbols" },
             { "cch", "Atsam" },
             { "mwr", "Marwari" },
-            { "type.kr.punct", "Punctuation" },
             { "type.nu.lanatham", "Tai Tham Tham Digits" },
             { "egl", "Emilian" },
             { "mwv", "Mentawai" },
@@ -217,6 +212,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.ss.standard", "Suppress Sentence Breaks After Standard Abbreviations" },
             { "CF", "Central African Republic" },
             { "CG", "Congo - Brazzaville" },
+            { "tgx", "Tagish" },
             { "CH", "Switzerland" },
             { "CI", "C\u00f4te d\u2019Ivoire" },
             { "CK", "Cook Islands" },
@@ -242,9 +238,11 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Pauc", "Pau Cin Hau" },
             { "vls", "West Flemish" },
             { "%%RIGIK", "Classic Volap\u00fck" },
+            { "kwk", "Kwak\u02bcwala" },
             { "Sogd", "Sogdian" },
             { "DE", "Germany" },
             { "goh", "Old High German" },
+            { "tht", "Tahltan" },
             { "ace", "Achinese" },
             { "cgg", "Chiga" },
             { "DG", "Diego Garcia" },
@@ -295,6 +293,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spain" },
             { "ET", "Ethiopia" },
+            { "Vith", "Vithkuqi" },
             { "EU", "European Union" },
             { "elx", "Elamite" },
             { "type.ca.gregorian", "Gregorian Calendar" },
@@ -318,7 +317,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "pcd", "Picard" },
             { "tkl", metaValue_TK },
             { "grb", "Grebo" },
-            { "root", "Root" },
             { "%%DAJNKO", "Dajnko alphabet" },
             { "type.ca.indian", "Indian National Calendar" },
             { "rgn", "Romagnol" },
@@ -326,6 +324,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "GA", "Gabon" },
             { "tkr", "Tsakhur" },
             { "vot", "Votic" },
+            { "type.nu.tnsa", "Tangsa Digits" },
             { "GB", "United Kingdom" },
             { "pcm", "Nigerian Pidgin" },
             { "GD", "Grenada" },
@@ -351,6 +350,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.k0.colemak", "Colemak Keyboard" },
             { "type.nu.mathmono", "Mathematical Monospace Digits" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "Rohingya" },
             { "tli", "Tlingit" },
             { "tlh", "Klingon" },
             { "Talu", "New Tai Lue" },
@@ -380,6 +380,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "nan", "Min Nan Chinese" },
             { "peo", metaValue_peo },
             { "ID", "Indonesia" },
+            { "clc", "Chilcotin" },
             { "Adlm", "Adlam" },
             { "type.nu.kali", "Kayah Li Digits" },
             { "IE", "Ireland" },
@@ -456,6 +457,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "LC", "St. Lucia" },
             { "Cyrs", "Old Church Slavonic Cyrillic" },
             { "gwi", "Gwich\u02bcin" },
+            { "type.m0.xaleget", "Eritrean Ministry of Education Blin-Latin Transliteration" },
             { "nds", "Low German" },
             { "LI", "Liechtenstein" },
             { "LK", "Sri Lanka" },
@@ -527,6 +529,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "%%UCRCOR", "Unified Revised Orthography" },
             { "NE", "Niger" },
             { "NF", "Norfolk Island" },
+            { "trw", "Torwali" },
             { "NG", "Nigeria" },
             { "trv", "Taroko" },
             { "Phlp", "Psalter Pahlavi" },
@@ -549,13 +552,20 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Mero", "Meroitic" },
             { "type.k0.ta99", "Tamil 99 Keyboard" },
             { "type.m0.c11", "Hex transform using C11 syntax" },
-            { "crh", "Crimean Turkish" },
+            { "crh", "Crimean Tatar" },
+            { "crg", "Michif" },
+            { "crj", "Southern East Cree" },
             { "ang", "Old English" },
+            { "crl", "Northern East Cree" },
+            { "crk", "Plains Cree" },
             { "OM", "Oman" },
+            { "crm", "Moose Cree" },
             { "anp", "Angika" },
+            { "crr", "Carolina Algonquian" },
             { "crs", "Seselwa Creole French" },
             { "type.nu.hmnp", "Nyiakeng Puachue Hmong Digits" },
             { "Xpeo", metaValue_peo },
+            { "ttm", "Northern Tutchone" },
             { "type.nu.hmng", "Pahawh Hmong Digits" },
             { "PA", "Panama" },
             { "sr_ME", "Montenegrin" },
@@ -578,6 +588,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Bali", metaValue_ban },
             { "PS", "Palestinian Territories" },
             { "PT", "Portugal" },
+            { "csw", "Swampy Cree" },
             { "PW", "Palau" },
             { "nia", "Nias" },
             { "type.nu.greklow", "Greek Lowercase Numerals" },
@@ -601,7 +612,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Tavt", "Tai Viet" },
             { "%%SOTAV", "Sotavento dialect group of Kabuverdianu" },
             { "Maka", metaValue_mak },
-            { "001", "World" },
+            { "001", "world" },
             { "002", "Africa" },
             { "njo", "Ao Naga" },
             { "003", "North America" },
@@ -628,6 +639,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Mand", "Mandaean" },
             { "SB", "Solomon Islands" },
             { "twq", "Tasawaq" },
+            { "Tnsa", "Tangsa" },
             { "011", "Western Africa" },
             { "SC", "Seychelles" },
             { "SD", "Sudan" },
@@ -680,6 +692,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "yav", "Yangben" },
             { "TD", "Chad" },
             { "Qaag", "Zawgyi" },
+            { "cwd", "Woods Cree" },
             { "TF", "French Southern Territories" },
             { "ase", "American Sign Language" },
             { "TG", "Togo" },
@@ -719,6 +732,8 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "lij", "Ligurian" },
             { "rup", "Aromanian" },
             { "030", "Eastern Asia" },
+            { "pqm", "Malecite" },
+            { "lil", "Lillooet" },
             { "type.nu.adlm", "Adlam Digits" },
             { "tyv", "Tuvinian" },
             { "sw_CD", "Congo Swahili" },
@@ -729,13 +744,14 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "hak", "Hakka Chinese" },
             { "type.co.pinyin", "Pinyin Sort Order" },
             { "039", "Southern Europe" },
+            { "atj", "Atikamekw" },
             { "Sinh", metaValue_si },
             { "UM", "U.S. Outlying Islands" },
             { "liv", "Livonian" },
             { "UN", "United Nations" },
             { "US", "United States" },
+            { "hax", "Southern Haida" },
             { "haw", "Hawaiian" },
-            { "type.kr.symbol", "Symbol" },
             { "%%1959ACAD", "Academic" },
             { "type.co.gb2312han", "Simplified Chinese Sort Order - GB2312" },
             { "UY", "Uruguay" },
@@ -758,12 +774,14 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Marc", "Marchen" },
             { "nog", "Nogai" },
             { "rwk", "Rwa" },
+            { "type.m0.gutgarts", "Yaros Gutgarts Ethiopic-Cyrillic Transliteration" },
             { "non", "Old Norse" },
             { "type.fw.sun", "First Day of Week Is Sunday" },
             { "053", "Australasia" },
             { "%%AREVMDA", "Western Armenian" },
             { "054", "Melanesia" },
             { "WF", "Wallis & Futuna" },
+            { "type.m0.tekieali", "Tekie Alibekit Blin-Latin Transliteration" },
             { "type.co.traditional", "Traditional Sort Order" },
             { "057", "Micronesian Region" },
             { "jgo", "Ngomba" },
@@ -785,11 +803,13 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "war", "Waray" },
             { "XB", "Pseudo-Bidi" },
             { "awa", "Awadhi" },
+            { "Kawi", metaValue_kaw },
             { "061", "Polynesia" },
             { "type.kv.punct", "Ignore Symbols affects spaces and punctuation only" },
             { "%%KSCOR", "Standard Orthography" },
             { "type.nu.segment", "Segmented Digits" },
             { "XK", "Kosovo" },
+            { "hdn", "Northern Haida" },
             { "type.nu.brah", "Brahmi Digits" },
             { "Gujr", metaValue_gu },
             { "Zxxx", "Unwritten" },
@@ -829,6 +849,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Runr", "Runic" },
             { "type.ms.metric", "Metric System" },
             { "type.ca.iso8601", "ISO-8601 Calendar" },
+            { "type.m0.aethiopi", "Encylopedia Aethiopica Transliteration" },
             { "lol", "Mongo" },
             { "nso", "Northern Sotho" },
             { "type.nu.telu", "Telugu Digits" },
@@ -836,7 +857,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "lou", "Louisiana Creole" },
             { "loz", "Lozi" },
             { "Nkgb", "Naxi Geba" },
-            { "type.kr.digit", "Digits" },
             { "type.lw.normal", "Normal Line Breaks For Words" },
             { "jmc", "Machame" },
             { "hif", "Fiji Hindi" },
@@ -854,7 +874,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Maya", "Mayan hieroglyphs" },
             { "type.k0.viqr", "Vietnamese VIQR Keyboard" },
             { "lrc", "Northern Luri" },
-            { "type.kr.space", "Whitespace" },
             { "type.co.emoji", "Emoji Sort Order" },
             { "Copt", metaValue_cop },
             { "nwc", "Classical Newari" },
@@ -903,6 +922,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "den", "Slave" },
             { "ban", metaValue_ban },
             { "uga", metaValue_uga },
+            { "type.m0.lambdin", "Thomas Oden Lambdin Ethiopic-Latin Transliteration" },
             { "type.nu.wara", "Warang Citi Digits" },
             { "fit", "Tornedalen Finnish" },
             { "luy", "Luyia" },
@@ -921,6 +941,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "bbc", "Batak Toba" },
             { "ae", metaValue_ae },
             { "af", "Afrikaans" },
+            { "hnj", "Hmong Njua" },
             { "type.k0.el220", "Greek 220 Keyboard" },
             { "ak", "Akan" },
             { "type.nu.cakm", "Chakma Digits" },
@@ -940,12 +961,13 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "sdh", "Southern Kurdish" },
             { "ay", "Aymara" },
             { "az", "Azerbaijani" },
-            { "Rohg", "Hanifi Rohingya" },
+            { "Rohg", "Hanifi" },
             { "type.va.posix", "POSIX Compliant Locale" },
             { "Khoj", "Khojki" },
             { "%%OSOJS", "Oseacco/Osojane dialect" },
             { "%%UNIFON", "Unifon phonetic alphabet" },
             { "ba", "Bashkir" },
+            { "type.lw.phrase", "Prevent Line Breaks In Phrases" },
             { "type.co.unihan", "Radical-Stroke Sort Order" },
             { "be", "Belarusian" },
             { "bg", "Bulgarian" },
@@ -1072,6 +1094,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "he", metaValue_he },
             { "hi", "Hindi" },
             { "hup", "Hupa" },
+            { "hur", "Halkomelem" },
             { "type.d0.fcc", "To Unicode FCC" },
             { "bik", "Bikol" },
             { "type.d0.fcd", "To Unicode FCD" },
@@ -1103,6 +1126,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "is", "Icelandic" },
             { "it", "Italian" },
             { "iu", "Inuktitut" },
+            { "slh", "Southern Lushootseed" },
             { "sli", "Lower Silesian" },
             { "type.k0.legacy", "Legacy Keyboard" },
             { "ja", metaValue_ja },
@@ -1122,6 +1146,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "mag", "Magahi" },
             { "maf", "Mafa" },
             { "mai", "Maithili" },
+            { "Ougr", "Old Uyghur" },
             { "smn", "Inari Sami" },
             { "ka", metaValue_ka },
             { "mak", metaValue_mak },
@@ -1147,6 +1172,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Avst", metaValue_ae },
             { "ku", "Kurdish" },
             { "kv", "Komi" },
+            { "blt", "Tai Dam" },
             { "kw", "Cornish" },
             { "ky", "Kyrgyz" },
             { "snk", "Soninke" },
@@ -1176,7 +1202,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "mh", "Marshallese" },
             { "type.fw.fri", "First Day of Week Is Friday" },
             { "type.co.ducet", "Default Unicode Sort Order" },
-            { "mi", "Maori" },
+            { "mi", "M\u0101ori" },
             { "mk", "Macedonian" },
             { "ml", metaValue_ml },
             { "mn", metaValue_mn },
@@ -1221,17 +1247,21 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "oj", "Ojibwa" },
             { "mer", "Meru" },
             { "type.nu.armn", "Armenian Numerals" },
+            { "Nagm", "Nag Mundari" },
             { "om", "Oromo" },
             { "type.i0.handwrit", "Handwriting Input Method" },
-            { "kaw", "Kawi" },
+            { "kaw", metaValue_kaw },
             { "dtp", "Central Dusun" },
             { "or", metaValue_or },
             { "Modi", "Modi" },
             { "os", "Ossetic" },
+            { "ojb", "Northwestern Ojibwa" },
             { "%%ALALC97", "ALA-LC Romanization, 1997 edition" },
+            { "ojc", "Central Ojibwa" },
             { "bpy", "Bishnupriya" },
             { "kbd", "Kabardian" },
             { "mfe", "Morisyen" },
+            { "ojg", "Eastern Ojibwa" },
             { "srn", "Sranan Tongo" },
             { "pa", "Punjabi" },
             { "dua", "Duala" },
@@ -1239,16 +1269,20 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "%%LIPAW", "The Lipovaz dialect of Resian" },
             { "kbl", "Kanembu" },
             { "pi", "Pali" },
+            { "ojs", "Oji-Cree" },
             { "bqi", "Bakhtiari" },
             { "pl", "Polish" },
             { "dum", "Middle Dutch" },
+            { "ojw", "Western Ojibwa" },
             { "type.nu.saur", "Saurashtra Digits" },
             { "type.ca.dangi", "Dangi Calendar" },
             { "type.m0.prprname", "Personal name transliteration variant" },
             { "ps", "Pashto" },
             { "pt", "Portuguese" },
+            { "oka", "Okanagan" },
             { "mga", "Middle Irish" },
             { "key.co", "Sort Order" },
+            { "type.d0.morse", "To Morse Code" },
             { "pt_BR", "Brazilian Portuguese" },
             { "%%BOHORIC", "Bohori\u010d alphabet" },
             { "kcg", "Tyap" },
@@ -1263,22 +1297,25 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.m0.css", "Hex transform using CSS syntax" },
             { "type.d0.publish", "To Publishing Characters From ASCII" },
             { "type.hc.h24", "24 Hour System (1\u201324)" },
+            { "type.m0.betamets", "Beta Ma\u1e63\u0101\u1e25\u01ddft Transliteration" },
             { "ssy", metaValue_ssy },
             { "brh", "Brahui" },
             { "type.nu.mymr", "Myanmar Digits" },
             { "qu", "Quechua" },
+            { "type.m0.sera", "System for Ethiopic Representation in ASCII" },
             { "zap", "Zapotec" },
             { "brx", "Bodo" },
             { "Lana", "Lanna" },
             { "kde", "Makonde" },
+            { "str", "Straits Salish" },
             { "stq", "Saterland Frisian" },
             { "Ethi", "Ethiopic" },
             { "type.hc.h12", "12 Hour System (1\u201312)" },
             { "type.hc.h11", "12 Hour System (0\u201311)" },
             { "type.nu.bhks", "Bhaiksuki Digits" },
             { "rm", "Romansh" },
-            { "key.cu", metaValue_key_cu },
             { "rn", "Rundi" },
+            { "key.cu", "Currency" },
             { "ro", "Romanian" },
             { "type.em.text", "Prefer Text Presentation For Emoji Characters" },
             { "%%SAAHO", metaValue_ssy },
@@ -1298,7 +1335,6 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "sc", "Sardinian" },
             { "sus", "Susu" },
             { "sd", "Sindhi" },
-            { "type.kr.currency", metaValue_key_cu },
             { "se", "Northern Sami" },
             { "min", "Minangkabau" },
             { "sg", "Sango" },
@@ -1335,6 +1371,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "143", "Central Asia" },
             { "type.s0.publish", "From Publishing Punctuation To ASCII" },
             { "te", metaValue_te },
+            { "Toto", "Toto" },
             { "145", "Western Asia" },
             { "tg", "Tajik" },
             { "th", metaValue_th },
@@ -1382,6 +1419,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "uz", "Uzbek" },
             { "kha", "Khasi" },
             { "%%1996", "German orthography of 1996" },
+            { "type.m0.iesjes", "IES/JES Amharic Transliteration" },
             { "nds_NL", "Low Saxon" },
             { "Sylo", "Syloti Nagri" },
             { "ve", "Venda" },
@@ -1403,12 +1441,14 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "type.k0.windows", "Windows Keyboard" },
             { "type.nu.gonm", "Masaram Gondi digits" },
             { "qug", "Chimborazo Highland Quichua" },
+            { "type.m0.gurage", "Gurage Legacy to Modern Transliteration" },
             { "Newa", "Newa" },
             { "gaa", "Ga" },
             { "wa", "Walloon" },
             { "key.em", "Emoji Presentation Style" },
             { "gag", "Gagauz" },
             { "syr", metaValue_syr },
+            { "Cpmn", "Cypro-Minoan" },
             { "type.nu.gong", "Gunjala Gondi digits" },
             { "Grek", metaValue_el },
             { "gan", "Gan Chinese" },
@@ -1421,6 +1461,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "Cans", "Unified Canadian Aboriginal Syllabics" },
             { "type.k0.var", "Keyboard Variant" },
             { "gay", "Gayo" },
+            { "key.dx", "Dictionary Break Exclusions" },
             { "Mong", metaValue_mn },
             { "type.k0.102key", "102-Key Keyboard" },
             { "mnc", "Manchu" },
@@ -1445,6 +1486,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "osa", metaValue_osa },
             { "byv", "Medumba" },
             { "gbz", "Zoroastrian Dari" },
+            { "moe", "Innu-aimun" },
             { "Moon", "Moon" },
             { "moh", "Mohawk" },
             { "key.kv", "Highest Ignored" },
@@ -1467,6 +1509,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "za", "Zhuang" },
             { "key.lw", "Line Breaks In Words Setting" },
             { "Cari", "Carian" },
+            { "type.s0.morse", "From Morse Code" },
             { "kln", "Kalenjin" },
             { "zh", "Chinese" },
             { "Afak", "Afaka" },
@@ -1502,15 +1545,18 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "ebu", "Embu" },
             { "Egyp", "Egyptian hieroglyphs" },
             { "Geok", "Georgian Khutsuri" },
+            { "ike", "Eastern Canadian Inuktitut" },
             { "zh_Hans", "Simplified Chinese" },
             { "koi", "Komi-Permyak" },
             { "Hung", "Old Hungarian" },
             { "kok", "Konkani" },
             { "%%1901", "Traditional German orthography" },
             { "kos", "Kosraean" },
+            { "ikt", "Western Canadian Inuktitut" },
             { "vec", "Venetian" },
             { "type.s0.accents", "From Accented Characters To ASCII Sequence" },
             { "type.nu.limb", "Limbu Digits" },
+            { "type.m0.es3842", "Ethiopian Standards Agency ES 3842:2014 Ethiopic-Latin Transliteration" },
             { "zh_Hant", "Traditional Chinese" },
             { "Sund", metaValue_su },
             { "vep", "Veps" },
@@ -1537,6 +1583,7 @@ public class LocaleNames_en extends OpenListResourceBundle {
             { "%%KKCOR", "Common Orthography" },
             { "Cher", metaValue_chr },
             { "car", "Carib" },
+            { "tce", "Southern Tutchone" },
             { "cay", "Cayuga" },
             { "type.nu.tamldec", "Tamil Digits" },
             { "krc", "Karachay-Balkar" },
