@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -71,6 +67,9 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
         final Object[][] data = new Object[][] {
+            { "CNY", "\u0938\u093f\u090f\u0928\u00a5" },
+            { "RUB", "\u0930\u0942\u092c" },
+            { "USD", "$" },
             { "adp", "\u0910\u0928\u094d\u0921\u094b\u0930\u093e \u0915\u093e \u092a\u0947\u0938\u0947\u0924\u093e" },
             { "aed", "\u0938\u0902\u092f\u0941\u0915\u094d\u0924 \u0905\u0930\u092c \u0905\u092e\u0940\u0930\u093e\u0924 \u0915\u093e \u0926\u093f\u0930\u094d\u0939\u093e\u092e" },
             { "afa", "\u0905\u092b\u093c\u0917\u093c\u093e\u0928\u0940 1927\u20132002" },
@@ -109,7 +108,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "brb", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0928\u092f\u093e \u0915\u094d\u0930\u0941\u091c\u093c\u0947\u0930\u094b (1967\u20131986)" },
             { "brc", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0915\u094d\u0930\u0941\u091c\u093c\u093e\u0921\u094b" },
             { "bre", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0915\u094d\u0930\u0941\u091c\u093c\u0947\u0930\u094b (190\u20131993)" },
-            { "brl", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0930\u0947\u092f\u093e\u0932" },
+            { "brl", "\u092c\u094d\u0930\u093e\u091c\u093f\u0932\u0928\u093f \u0930\u0940\u092f\u093e\u0932" },
             { "brn", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0928\u092f\u093e \u0915\u094d\u0930\u0941\u091c\u093c\u093e\u0921\u094b" },
             { "brr", "\u092c\u094d\u0930\u091c\u093c\u0940\u0932\u0940 \u0915\u094d\u0930\u0941\u091c\u093c\u0947\u0930\u094b" },
             { "bsd", "\u092c\u0939\u093e\u092e\u093e \u0921\u0949\u0932\u0930" },
@@ -127,7 +126,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "chw", "\u0906\u0908\u0930\u0932\u0948\u0923\u094d\u0921 \u0915\u093e \u092b\u093c\u094d\u0930\u0948\u0902\u0915" },
             { "clf", "\u091a\u0940\u0932\u0940 \u0915\u093e \u090a\u0928\u0940\u0926\u093e\u0926\u0947\u0938 \u0926 \u092b\u094b\u092e\u0947\u0902\u091f\u094b" },
             { "clp", "\u091a\u093f\u0932\u0940 \u092a\u0947\u0938\u094b" },
-            { "cny", "\u091a\u0940\u0928\u0940 \u092f\u0941\u0906\u0928 \u0930\u0947\u0928\u092e\u0940\u0928\u092c\u0940" },
+            { "cny", "\u091a\u093e\u0907\u0928\u0940\u091c \u092f\u0941\u0935\u093e\u0928" },
             { "cop", "\u0915\u094b\u0932\u092e\u094d\u092c\u093f\u092f\u093e\u0908 \u092a\u0947\u0938\u094b" },
             { "cou", "\u092f\u0941\u0928\u0940\u0926\u093e\u0926 \u0926 \u0935\u093e\u0932\u094b\u0930 \u0930\u0947\u0906\u0932" },
             { "crc", "\u0915\u0949\u0938\u094d\u091f\u093e \u0930\u0940\u0915\u093e \u0915\u093e \u0915\u094b\u0932\u094b\u0928" },
@@ -157,7 +156,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "fjd", "\u092b\u093c\u093f\u091c\u0940 \u0915\u093e \u0921\u0949\u0932\u0930" },
             { "fkp", "\u092b\u093e\u0932\u094d\u0915\u0932\u0948\u0923\u094d\u0921 \u0926\u094d\u0935\u0940\u092a \u092a\u094c\u0923\u094d\u0921" },
             { "frf", "\u092b\u094d\u0930\u093e\u0901\u0938\u0940\u0938\u0940 \u092b\u094d\u0930\u093e\u0901" },
-            { "gbp", "\u092c\u094d\u0930\u093f\u0924\u0928 \u0915\u093e \u092a\u094c\u0923\u094d\u0921 \u0938\u094d\u091f\u0930\u094d\u0932\u093f\u0917" },
+            { "gbp", "\u092c\u094d\u0930\u093f\u091f\u093f\u0936 \u092a\u093e\u0909\u0923\u094d\u0921" },
             { "gek", "\u091c\u0949\u0930\u094d\u091c\u093f\u092f\u093e \u0915\u093e \u0915\u0941\u092a\u094b\u0928 \u0932\u093e\u0930\u0940\u0924" },
             { "gel", "\u091c\u0949\u0930\u094d\u091c\u093f\u092f\u093e \u0915\u093e \u0932\u093e\u0930\u0940" },
             { "ghc", "\u0918\u093e\u0928\u093e \u091a\u0947\u0926\u0940 (1979\u20132007)" },
@@ -182,7 +181,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "iep", "\u0906\u0908\u0930\u0940\u0936 \u092a\u094c\u0902\u0921" },
             { "ilp", "\u0907\u0938\u094d\u0930\u093e\u0907\u0932\u0940 \u092a\u094c\u0902\u0921" },
             { "ils", "\u0907\u0938\u094d\u0930\u093e\u0907\u0932\u0940 \u0936\u0947\u0915\u0947\u0932" },
-            { "inr", "\u0930\u093e\u0902" },
+            { "inr", "\u092d\u093e\u0930\u0924\u0928\u093f \u0930\u0941\u092a\u0940" },
             { "iqd", "\u0908\u0930\u093e\u0915\u093c\u0940 \u0926\u0940\u0928\u093e\u0930" },
             { "irr", "\u0908\u0930\u093e\u0928\u0940 \u0930\u0940\u092f\u093e\u0932" },
             { "isk", "\u0906\u0908\u0938\u0932\u0948\u0923\u094d\u0921 \u0915\u094d\u0930\u094b\u0928\u093e" },
@@ -260,7 +259,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "rol", "\u0930\u094b\u092e\u093e\u0928\u093f\u092f\u093e\u0908 \u092a\u0941\u0930\u093e\u0928\u0940 \u0932" },
             { "ron", "\u0930\u094b\u092e\u093e\u0928\u093f\u092f\u093e\u0908 \u0932" },
             { "rsd", "\u0938\u0930\u094d\u092c\u093f\u092f\u093e\u0908 \u0926\u093f\u0928\u093e\u0930" },
-            { "rub", "\u0930\u0942\u0938\u0940 \u0930\u0942\u092c\u0932" },
+            { "rub", "\u0930\u093e\u0938\u093f\u092f\u093e\u0928\u093f \u0930\u0942\u092c\u0932" },
             { "rwf", "\u0930\u0941\u0906\u0901\u0926\u093e \u092b\u094d\u0930\u093e\u0901" },
             { "sar", "\u0938\u093e\u0909\u0926\u0940 \u0930\u093f\u092f\u093e\u0932" },
             { "sbd", "\u0938\u094b\u0932\u094b\u092e\u0928 \u0926\u094d\u0935\u0940\u092a \u0915\u093e \u0921\u0949\u0932\u0930" },
@@ -299,7 +298,7 @@ public class CurrencyNames_brx extends OpenListResourceBundle {
             { "uak", "\u092f\u0941\u0915\u094d\u0930\u0947\u0928\u0940 \u0915\u093e\u0930\u094d\u092c\u094b\u0935\u093e\u0928\u0947\u0924\u094d\u091c\u093c" },
             { "ugs", "\u092f\u0941\u0917\u093e\u0901\u0921\u093e\u0908 \u0936\u0940\u0932\u0940\u0902\u0917 (1996\u20131987)" },
             { "ugx", "\u092f\u0941\u0917\u093e\u0901\u0921\u093e\u0908 \u0936\u0940\u0932\u0940\u0902\u0917" },
-            { "usd", "\u0905\u092e\u0930\u093f\u0915\u0940 \u0921\u0949\u0932\u0930" },
+            { "usd", "\u0907\u0909.\u090f\u0938 \u0921\u0932\u093e\u0930" },
             { "usn", "\u0905\u092e\u0930\u093f\u0915\u0940 \u0921\u0949\u0932\u0930 (\u0905\u0917\u0932\u0947 \u0926\u093f\u0928 \u0915\u093e)" },
             { "uss", "\u0905\u092e\u0930\u093f\u0915\u0940 \u0921\u0949\u0932\u0930 (\u0907\u0938\u0940 \u0926\u093f\u0928 \u0915\u093e)" },
             { "uyi", "\u090a\u0930\u0941\u0917\u0941\u090f \u0915\u093e \u092a\u0947\u0938\u094b \u0906\u0928 \u090a\u0928\u0940\u0926\u093e\u0926\u094b\u0938 \u0908\u0902\u0926\u0947\u0915\u094d\u0938\u093e\u0926\u093e\u0938" },
