@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -612,7 +608,7 @@ public class CurrencyNames_gd extends OpenListResourceBundle {
             { "uyi", "Peso Uruguaidheach (aonadan inneacsaichte)" },
             { "uyp", "Peso Uruguaidheach (1975\u20131993)" },
             { "uyu", "Peso Uruguaidheach" },
-            { "uyw", "aonad inneacs tuarastail ainmeach Uruguaidh" },
+            { "uyw", "Aonad inneacs tuarastail ainmeach Uruguaidh" },
             { "uzs", "Som Usbagach" },
             { "veb", "Bol\u00edvar Bheinisealach (1871\u20132008)" },
             { "vef", "Bol\u00edvar Bheinisealach (2008\u20132018)" },
