@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -331,7 +327,7 @@ public class CurrencyNames_is extends OpenListResourceBundle {
             { "lbp", "l\u00edbanskt pund" },
             { "lkr", "sr\u00edl\u00f6nsk r\u00fap\u00eda" },
             { "lrd", "l\u00edber\u00edskur dalur" },
-            { "lsl", "Lesotho Loti" },
+            { "lsl", "les\u00f3t\u00f3skur l\u00f3ti" },
             { "ltl", "Lith\u00e1\u00edskt l\u00edt" },
             { "ltt", "Lithuanian Talonas" },
             { "luf", "L\u00faxemborgarfranki" },
@@ -364,7 +360,7 @@ public class CurrencyNames_is extends OpenListResourceBundle {
             { "nad", "namib\u00edskur dalur" },
             { "ngn", "n\u00edger\u00edsk n\u00e6ra" },
             { "nic", "N\u00edkar\u00f6gsk kord\u00f3va (1988\u20131991)" },
-            { "nio", "n\u00edkara\u00f6gsk kord\u00f3va" },
+            { "nio", "n\u00edkar\u00f6gsk kord\u00f3va" },
             { "nlg", "Hollenskt gyllini" },
             { "nok", "norsk kr\u00f3na" },
             { "npr", "nep\u00f6lsk r\u00fap\u00eda" },
