@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -143,6 +139,7 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "LBP", "LBP" },
             { "LKR", "LKR" },
             { "LRD", "LRD" },
+            { "LSL", "\u041b\u0421\u041b" },
             { "LYD", "LYD" },
             { "MAD", "MAD" },
             { "MDL", "MDL" },
@@ -291,6 +288,7 @@ public class CurrencyNames_kk extends OpenListResourceBundle {
             { "lbp", "\u041b\u0438\u0432\u0430\u043d \u0444\u0443\u043d\u0442\u044b" },
             { "lkr", "\u0428\u0440\u0438-\u041b\u0430\u043d\u043a\u0430 \u0440\u0443\u043f\u0438\u044f\u0441\u044b" },
             { "lrd", "\u041b\u0438\u0431\u0435\u0440\u0438\u044f \u0434\u043e\u043b\u043b\u0430\u0440\u044b" },
+            { "lsl", "\u041b\u0435\u0441\u043e\u0442\u043e \u043b\u043e\u0442\u0438\u0456" },
             { "ltl", "\u041b\u0438\u0442\u0432\u0430 \u043b\u0438\u0442\u044b" },
             { "lvl", "\u041b\u0430\u0442\u0432\u0438\u044f \u043b\u0430\u0442\u044b" },
             { "lyd", "\u041b\u0438\u0432\u0438\u044f \u0434\u0438\u043d\u0430\u0440\u044b" },
