@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -236,7 +232,6 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "pcd", "pikardeg" },
             { "tkl", "tokelau" },
             { "grb", "grebo" },
-            { "root", "gwrizienn" },
             { "%%DAJNKO", "lizherenneg Dajnko" },
             { "type.ca.indian", "deiziadur indian" },
             { "rgn", "romagnoleg" },
@@ -499,6 +494,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "015", "Afrika an Norzh" },
             { "SG", "Singapour" },
             { "SH", "Saint-Helena" },
+            { "type.lb.strict", "stil torr linenn strizh" },
             { "017", "Afrika ar C\u02bchreiz" },
             { "SI", "Slovenia" },
             { "018", "Afrika ar Su" },
@@ -635,6 +631,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%NEWFOUND", "saozneg an Douar-Nevez" },
             { "ZA", "Suafrika" },
             { "type.nu.sund", "sifro\u00f9 sundanek" },
+            { "type.lb.loose", "stil torr linenn lezober" },
             { "Deva", "devanagari" },
             { "type.nu.geor", "nivero\u00f9 jorjianek" },
             { "type.co.zhuyin", "urzh rumma\u00f1 Zhuyin" },
@@ -779,6 +776,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "dje", "zarma" },
             { "type.nu.grek", "nivero\u00f9 gresianek" },
             { "ee", "ewe" },
+            { "type.lb.normal", "stil torr linenn boas" },
             { "ro_MD", "moldoveg" },
             { "el", "gresianeg" },
             { "en", "saozneg" },
@@ -1008,7 +1006,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "ru", "rusianeg" },
             { "bss", "akoose" },
             { "rw", "kinyarwanda" },
-            { "zbl", "Bliss" },
+            { "zbl", "arouezio\u00f9 Bliss" },
             { "kea", "kabuverdianu" },
             { "mic", "mikmakeg" },
             { "suk", "sukuma" },
@@ -1035,6 +1033,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "sr", "serbeg" },
             { "ListKeyTypePattern", "{0} : {1}" },
             { "ss", "swati" },
+            { "type.cf.account", "furmad unanenn jedi\u00f1" },
             { "st", "sotho ar Su" },
             { "Java", "javanek" },
             { "su", "sundaneg" },
@@ -1151,6 +1150,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "kln", "kalendjineg" },
             { "zh", "sinaeg" },
             { "Bopo", "bopomofo" },
+            { "key.lb", "stil torr linenn" },
             { "zu", "zouloueg" },
             { "type.co.phonebook", "urzh rumma\u00f1 al levr-pellgomz" },
             { "%%MONOTON", "gresianeg untonel" },
@@ -1193,6 +1193,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "%%IJEKAVSK", "serbeg gant distagadur ijekavian" },
             { "mua", "moundangeg" },
             { "type.nu.guru", "sifro\u00f9 gurmukhi" },
+            { "%%BORNHOLM", "rannyezh Bornholm" },
             { "mul", "yezho\u00f9 lies" },
             { "%%PUTER", "rannyezh roma\u00f1chek Puter" },
             { "cad", "caddo" },
@@ -1207,6 +1208,7 @@ public class LocaleNames_br extends OpenListResourceBundle {
             { "krc", "karatchay-balkar" },
             { "inh", "ingoucheg" },
             { "kri", "krio" },
+            { "fa_AF", "dareg" },
             { "krl", "karelieg" },
             { "%%OXENDICT", "skritur Oxford English Dictionary" },
             { "efi", "efik" },
