@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -96,12 +92,12 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "AO", "Angola" },
             { "Jpan", metaValue_ja },
             { "AQ", "Antarctica" },
-            { "001", "Kalibutan" },
+            { "001", "kalibutan" },
             { "AR", "Argentina" },
             { "ar", "Arabic" },
             { "002", "Africa" },
             { "AS", "American Samoa" },
-            { "003", "North America" },
+            { "003", "Amihanang Amerika" },
             { "AT", "Austria" },
             { "RE", "Reunion" },
             { "AU", "Australia" },
@@ -236,7 +232,7 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "039", "Southern Europe" },
             { "DZ", "Algeria" },
             { "UM", "U.S. Outlying Islands" },
-            { "UN", "United Nations" },
+            { "UN", "Hiniusang Kanasoran" },
             { "EA", "Ceuta & Melilla" },
             { "EC", "Ecuador" },
             { "US", "Estados Unidos" },
@@ -249,7 +245,7 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "VA", "Vatican City" },
             { "ER", "Eritrea" },
             { "VC", "St. Vincent & Grenadines" },
-            { "ES", "Spain" },
+            { "ES", "Espanya" },
             { "es", "Espanyol" },
             { "ET", "Ethiopia" },
             { "VE", "Venezuela" },
@@ -338,7 +334,7 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "JO", "Jordan" },
             { "JP", "Japan" },
             { "type.ca.iso8601", "Kalendaryo sa ISO-8601" },
-            { "de_CH", "Swiss nga Taas nga Aleman" },
+            { "de_CH", "Taas nga Aleman sa Switzerland" },
             { "KE", "Kenya" },
             { "419", "Latin America" },
             { "KG", "Kyrgyzstan" },
@@ -350,7 +346,7 @@ public class LocaleNames_ceb extends OpenListResourceBundle {
             { "ko", metaValue_ko },
             { "KP", "North Korea" },
             { "KR", "South Korea" },
-            { "fr_CH", "Swiss nga Pranses" },
+            { "fr_CH", "Pranses sa Switzerland" },
             { "KW", "Kuwait" },
             { "KY", "Cayman Islands" },
             { "KZ", "Kazakhstan" },
