@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -246,7 +242,6 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "pcd", "picard\u0161tina" },
             { "tkl", "tokelau\u0161tina" },
             { "grb", "grebo" },
-            { "root", "ko\u0159en" },
             { "type.ca.indian", "Indick\u00fd n\u00e1rodn\u00ed kalend\u00e1\u0159" },
             { "rgn", "roma\u0148ol\u0161tina" },
             { "grc", "staro\u0159e\u010dtina" },
@@ -275,6 +270,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "pdc", "n\u011bm\u010dina (pensylv\u00e1nsk\u00e1)" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "rohing\u0161tina" },
             { "tli", "tlingit" },
             { "tlh", "klingon\u0161tina" },
             { "Talu", "tai l\u00fc nov\u00e9" },
@@ -445,7 +441,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "Merc", "meroitick\u00e9 psac\u00ed" },
             { "rom", "rom\u0161tina" },
             { "Mero", "meroitick\u00e9" },
-            { "crh", "ture\u010dtina (krymsk\u00e1)" },
+            { "crh", "tatar\u0161tina (krymsk\u00e1)" },
             { "ang", "staroangli\u010dtina" },
             { "OM", "Om\u00e1n" },
             { "anp", "angika" },
@@ -546,7 +542,7 @@ public class LocaleNames_cs extends OpenListResourceBundle {
             { "SX", "Svat\u00fd Martin (Nizozemsko)" },
             { "SY", "S\u00fdrie" },
             { "yao", "jao\u0161tina" },
-            { "SZ", "Svazijsko" },
+            { "SZ", "Eswatini" },
             { "arw", "arawack\u00e9 jazyky" },
             { "arz", "arab\u0161tina (egyptsk\u00e1)" },
             { "ary", "arab\u0161tina (marock\u00e1)" },
