@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -108,7 +104,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "AW", "Aruba" },
             { "en_US", "Saesneg America" },
             { "AX", "Ynysoedd \u00c5land" },
-            { "AZ", "Azerbaijan" },
+            { "AZ", "Aserbaijan" },
             { "%%AREVELA", "Armeneg Dwyreiniol" },
             { "BA", "Bosnia a Herzegovina" },
             { "BB", "Barbados" },
@@ -215,7 +211,6 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "FR", "Ffrainc" },
             { "pcd", "Picardeg" },
             { "tkl", "Tocelaweg" },
-            { "root", "Y Gwraidd" },
             { "%%DAJNKO", "gwyddor Dajnko" },
             { "type.ca.indian", "Calendr Cenedlaethol India" },
             { "grc", "Hen Roeg" },
@@ -234,15 +229,16 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "GL", "Yr Ynys Las" },
             { "enm", "Saesneg Canol" },
             { "GM", "Gambia" },
-            { "GN", "Guin\u00e9e" },
+            { "GN", "Gini" },
             { "GP", "Guadeloupe" },
-            { "GQ", "Guinea Gyhydeddol" },
+            { "GQ", "Gini Gyhydeddol" },
             { "GR", "Gwlad Groeg" },
             { "GS", "De Georgia ac Ynysoedd Sandwich y De" },
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "pdc", "Almaeneg Pensylfania" },
             { "GW", "Guin\u00e9-Bissau" },
+            { "rhg", "Rohingya" },
             { "tli", "Llingit" },
             { "tlh", "Klingon" },
             { "GY", "Guyana" },
@@ -250,7 +246,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "zxx", "Dim cynnwys ieithyddol" },
             { "tly", "Talysheg" },
             { "de_AT", "Almaeneg Awstria" },
-            { "HK", "Hong Kong SAR Tseina" },
+            { "HK", "Hong Kong SAR Tsieina" },
             { "HM", "Ynys Heard ac Ynysoedd McDonald" },
             { "HN", "Honduras" },
             { "HR", "Croatia" },
@@ -292,7 +288,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "guz", "Gusii" },
             { "type.nu.knda", "Digidau Kannaraidd" },
             { "de_CH", "Almaeneg Safonol y Swistir" },
-            { "type.ca.buddhist", "Calendr y Bwdiaid" },
+            { "type.ca.buddhist", "Calendr Bwdaidd" },
             { "KE", "Kenya" },
             { "419", "America Ladin" },
             { "KG", "Kyrgyzstan" },
@@ -302,13 +298,13 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "KN", "Saint Kitts a Nevis" },
             { "Knda", "Canaraidd" },
             { "fr_CA", "Ffrangeg Canada" },
-            { "KP", "Gogledd Korea" },
-            { "KR", "De Korea" },
+            { "KP", "Gogledd Corea" },
+            { "KR", "De Corea" },
             { "fr_CH", "Ffrangeg y Swistir" },
             { "KW", "Kuwait" },
             { "tpi", "Tok Pisin" },
             { "KY", "Ynysoedd Cayman" },
-            { "KZ", "Kazakstan" },
+            { "KZ", "Kazakhstan" },
             { "Cyrl", "Cyrilig" },
             { "LA", "Laos" },
             { "LB", "Libanus" },
@@ -322,7 +318,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "cop", "Copteg" },
             { "LR", "Liberia" },
             { "LS", "Lesotho" },
-            { "LT", "Lithuania" },
+            { "LT", "Lithwania" },
             { "LU", "Lwcsembwrg" },
             { "LV", "Latfia" },
             { "Kana", "Catacana" },
@@ -348,7 +344,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "Newaeg" },
-            { "MO", "Macau RhGA Tsieina" },
+            { "MO", "Macau SAR Tsieina" },
             { "aln", "Ghegeg Albania" },
             { "MP", "Ynysoedd Gogledd Mariana" },
             { "MQ", "Martinique" },
@@ -365,7 +361,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "MZ", "Mozambique" },
             { "NA", "Namibia" },
             { "202", "Affrica Is-Sahara" },
-            { "type.ca.hebrew", "Calendr yr Hebraed" },
+            { "type.ca.hebrew", "Calendr Hebreaidd" },
             { "type.co.dictionary", "Trefn Geiriadur" },
             { "NC", "Caledonia Newydd" },
             { "NE", "Niger" },
@@ -478,18 +474,18 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "021", "America i\u2019r Gogledd o Fecsico" },
             { "TC", "Ynysoedd Turks a Caicos" },
             { "yav", "Iangben" },
-            { "TD", "Tchad" },
+            { "TD", "Tsiad" },
             { "TF", "Tiroedd Deheuol ac Antarctig Ffrainc" },
             { "ase", "Iaith Arwyddion America" },
             { "TG", "Togo" },
             { "TH", "Gwlad Thai" },
-            { "TJ", "Tajikistan" },
+            { "TJ", "Tajicistan" },
             { "029", "Y Carib\u00ee" },
             { "TK", "Tokelau" },
             { "TL", "Timor-Leste" },
             { "ybb", "Iembaeg" },
-            { "TM", "Turkmenistan" },
-            { "TN", "Tunisia" },
+            { "TM", "Tyrcmenistan" },
+            { "TN", "Tiwnisia" },
             { "TO", "Tonga" },
             { "TR", "Twrci" },
             { "TT", "Trinidad a Tobago" },
@@ -671,7 +667,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "cy", "Cymraeg" },
             { "type.nu.ethi", "Rhifolion Ethiopig" },
             { "da", "Daneg" },
-            { "pt_PT", "Portiwgeeg Ewrop" },
+            { "pt_PT", "Portiwgaleg Ewrop" },
             { "de", "Almaeneg" },
             { "type.cf.standard", "Fformat Arian Safonol" },
             { "bej", "Bej\u00e4eg" },
@@ -810,7 +806,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "mg", "Malagaseg" },
             { "mh", "Marsialeg" },
             { "type.co.ducet", "Trefn Rhagosodedig Unicode" },
-            { "mi", "Maori" },
+            { "mi", "M\u0101ori" },
             { "mk", "Macedoneg" },
             { "ml", "Malayalam" },
             { "mn", "Mongoleg" },
@@ -859,10 +855,10 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "dum", "Iseldireg Canol" },
             { "type.ca.dangi", "Calendr Dangi" },
             { "ps", "Pashto" },
-            { "pt", "Portiwgeeg" },
+            { "pt", "Portiwgaleg" },
             { "mga", "Gwyddeleg Canol" },
             { "key.co", "Trefn" },
-            { "pt_BR", "Portiwgeeg Brasil" },
+            { "pt_BR", "Portiwgaleg Brasil" },
             { "%%BOHORIC", "Gwyddor Bohori\u010d" },
             { "kcg", "Tyapeg" },
             { "mgh", "Makhuwa-Meetto" },
@@ -981,7 +977,7 @@ public class LocaleNames_cy extends OpenListResourceBundle {
             { "syr", "Syrieg" },
             { "Grek", "Groegaidd" },
             { "wo", "Woloff" },
-            { "zgh", "Tamaseit Safonol" },
+            { "zgh", "Tamaseit Moroco Safonol" },
             { "ar_001", "Arabeg Modern Safonol" },
             { "gay", "Gaio" },
             { "Mong", "Mongolaidd" },
