@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -98,6 +94,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
         final String metaValue_tl = "Tagalog";
         final String metaValue_zh = "Chinesisch";
         final String metaValue_ban = "Balinesisch";
+        final String metaValue_bas = "Bassa";
         final String metaValue_bax = "Bamun";
         final String metaValue_bug = "Buginesisch";
         final String metaValue_ccp = "Chakma";
@@ -184,7 +181,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "myv", "Ersja-Mordwinisch" },
             { "BN", "Brunei Darussalam" },
             { "BO", "Bolivien" },
-            { "BQ", "Bonaire, Sint Eustatius und Saba" },
+            { "BQ", "Karibische Niederlande" },
             { "BR", "Brasilien" },
             { "BS", "Bahamas" },
             { "xog", "Soga" },
@@ -291,7 +288,6 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "pcd", "Picardisch" },
             { "tkl", "Tokelauanisch" },
             { "grb", "Grebo" },
-            { "root", "Root" },
             { "type.ca.indian", "Indischer Nationalkalender" },
             { "rgn", "Romagnol" },
             { "grc", "Altgriechisch" },
@@ -320,6 +316,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "pdc", "Pennsylvaniadeutsch" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "Rohingyalisch" },
             { "tli", "Tlingit" },
             { "tlh", "Klingonisch" },
             { "Talu", "Tai Lue" },
@@ -632,7 +629,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "TT", "Trinidad und Tobago" },
             { "TV", "Tuvalu" },
             { "TW", "Taiwan" },
-            { "ast", "Asturianisch" },
+            { "ast", "Asturisch" },
             { "rue", "Russinisch" },
             { "rug", "Roviana" },
             { "Orkh", "Orchon-Runen" },
@@ -692,7 +689,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "type.co.compat", "vorherige Sortierung, Kompatibilit\u00e4t" },
             { "wae", "Walliserdeutsch" },
             { "WS", "Samoa" },
-            { "Bass", "Bassa" },
+            { "Bass", metaValue_bas },
             { "type.nu.mtei", "Meitei-Mayek-Ziffern" },
             { "wal", "Walamo" },
             { "was", "Washo" },
@@ -796,7 +793,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "fit", "Me\u00e4nkieli" },
             { "luy", "Luhya" },
             { "bar", "Bairisch" },
-            { "bas", "Basaa" },
+            { "bas", metaValue_bas },
             { "bax", metaValue_bax },
             { "jrb", "J\u00fcdisch-Arabisch" },
             { "nzi", "Nzima" },
@@ -830,7 +827,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "%%OSOJS", "Osojane-Dialekt" },
             { "ba", "Baschkirisch" },
             { "type.co.unihan", "Radikal-Strich-Sortierregeln" },
-            { "be", "Wei\u00dfrussisch" },
+            { "be", "Belarussisch" },
             { "bg", "Bulgarisch" },
             { "bi", "Bislama" },
             { "type.nu.java", "Javanesische Ziffern" },
@@ -923,7 +920,7 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "sid", "Sidamo" },
             { "fy", "Westfriesisch" },
             { "ga", "Irisch" },
-            { "gd", "Schottisches G\u00e4lisch" },
+            { "gd", "G\u00e4lisch (Schottland)" },
             { "gl", "Galicisch" },
             { "gn", "Guaran\u00ed" },
             { "bho", "Bhodschpuri" },
@@ -1024,10 +1021,10 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "lu", "Luba-Katanga" },
             { "lv", "Lettisch" },
             { "sog", "Sogdisch" },
-            { "mg", "Madagassisch" },
+            { "mg", "Malagasy" },
             { "mh", "Marschallesisch" },
             { "type.co.ducet", "Unicode-Sortierung" },
-            { "mi", "Maori" },
+            { "mi", "M\u0101ori" },
             { "mk", "Mazedonisch" },
             { "ml", metaValue_ml },
             { "mn", metaValue_mn },
@@ -1042,13 +1039,13 @@ public class LocaleNames_de extends OpenListResourceBundle {
             { "dsb", "Niedersorbisch" },
             { "na", "Nauruisch" },
             { "type.co.search", "allgemeine Suche" },
-            { "nb", "Norwegisch Bokm\u00e5l" },
+            { "nb", "Norwegisch (Bokm\u00e5l)" },
             { "nd", "Nord-Ndebele" },
             { "ne", "Nepalesisch" },
             { "ng", "Ndonga" },
             { "mdr", "Mandaresisch" },
             { "nl", "Niederl\u00e4ndisch" },
-            { "nn", "Norwegisch Nynorsk" },
+            { "nn", "Norwegisch (Nynorsk)" },
             { "no", "Norwegisch" },
             { "nr", "S\u00fcd-Ndebele" },
             { "nv", "Navajo" },
