@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -75,6 +71,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
         final String metaValue_bn = "bengal\u00ed";
         final String metaValue_bo = "tibetano";
         final String metaValue_el = "griego";
+        final String metaValue_gu = "guyarat\u00ed";
         final String metaValue_he = "hebreo";
         final String metaValue_hy = "armenio";
         final String metaValue_ja = "japon\u00e9s";
@@ -83,6 +80,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
         final String metaValue_km = "jemer";
         final String metaValue_kn = "canar\u00e9s";
         final String metaValue_ko = "coreano";
+        final String metaValue_ml = "malay\u00e1lam";
         final String metaValue_mn = "mongol";
         final String metaValue_my = "birmano";
         final String metaValue_or = "oriya";
@@ -142,7 +140,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "AU", "Australia" },
             { "AW", "Aruba" },
             { "en_US", "ingl\u00e9s estadounidense" },
-            { "AX", "Islas \u00c5land" },
+            { "AX", "Islas Aland" },
             { "mye", "myene" },
             { "AZ", "Azerbaiy\u00e1n" },
             { "%%AREVELA", "Armenio oriental" },
@@ -246,7 +244,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "EU", "Uni\u00f3n Europea" },
             { "elx", "elamita" },
             { "type.ca.gregorian", "calendario gregoriano" },
-            { "EZ", "zona euro" },
+            { "EZ", "zona del euro" },
             { "chy", "cheyene" },
             { "type.nu.gujr", "d\u00edgitos en guyarat\u00ed" },
             { "Inds", "Indio (harappan)" },
@@ -261,7 +259,6 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "FR", "Francia" },
             { "tkl", "tokelauano" },
             { "grb", "grebo" },
-            { "root", "ra\u00edz" },
             { "type.ca.indian", "calendario nacional hind\u00fa" },
             { "grc", "griego antiguo" },
             { "GA", "Gab\u00f3n" },
@@ -271,7 +268,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "GD", "Granada" },
             { "GE", "Georgia" },
             { "GF", "Guayana Francesa" },
-            { "GG", "Guernsey" },
+            { "GG", "Guernesey" },
             { "GH", "Ghana" },
             { "Tale", "tai le" },
             { "GI", "Gibraltar" },
@@ -287,6 +284,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "GW", "Guinea-Bis\u00e1u" },
+            { "rhg", "rohiny\u00e1" },
             { "tli", "tlingit" },
             { "tlh", "klingon" },
             { "Talu", "nuevo tai lue" },
@@ -608,7 +606,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "awa", "avadhi" },
             { "061", "Polinesia" },
             { "XK", "Kosovo" },
-            { "Gujr", "gujarati" },
+            { "Gujr", metaValue_gu },
             { "Zxxx", "no escrito" },
             { "Olck", "ol ciki" },
             { "wbp", "warlpiri" },
@@ -771,7 +769,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "type.co.big5han", "orden del chino tradicional - Big5" },
             { "es", "espa\u00f1ol" },
             { "et", "estonio" },
-            { "Hanb", "hanb" },
+            { "Hanb", "han con bopomofo" },
             { "eu", "euskera" },
             { "Buhd", "buhid" },
             { "Hang", "hangul" },
@@ -805,7 +803,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "bho", "bhoyapur\u00ed" },
             { "und", "lengua desconocida" },
             { "type.ca.ethiopic-amete-alem", "calendario et\u00edope Amete Alem" },
-            { "gu", "guyarat\u00ed" },
+            { "gu", metaValue_gu },
             { "gv", "man\u00e9s" },
             { "ha", "hausa" },
             { "he", metaValue_he },
@@ -838,7 +836,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "it", "italiano" },
             { "iu", "inuktitut" },
             { "ja", metaValue_ja },
-            { "Mlym", "malay\u00e1lam" },
+            { "Mlym", metaValue_ml },
             { "Sara", "sarati" },
             { "doi", "dogri" },
             { "bkm", "kom" },
@@ -868,7 +866,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "kn", metaValue_kn },
             { "ko", metaValue_ko },
             { "kr", "kanuri" },
-            { "ks", "cachemiro" },
+            { "ks", "cachemir" },
             { "Cirt", "cirth" },
             { "Lepc", "lepcha" },
             { "Avst", metaValue_ae },
@@ -879,7 +877,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "snk", "sonink\u00e9" },
             { "la", "lat\u00edn" },
             { "lb", "luxemburgu\u00e9s" },
-            { "type.nu.mlym", "d\u00edgitos en malayalam" },
+            { "type.nu.mlym", "d\u00edgitos en malay\u00e1lam" },
             { "lg", "ganda" },
             { "Roro", "rongo-rongo" },
             { "li", "limburgu\u00e9s" },
@@ -897,7 +895,7 @@ public class LocaleNames_es extends OpenListResourceBundle {
             { "type.co.ducet", "orden predeterminado de Unicode" },
             { "mi", "maor\u00ed" },
             { "mk", "macedonio" },
-            { "ml", "malayalam" },
+            { "ml", metaValue_ml },
             { "mn", metaValue_mn },
             { "mr", "marat\u00ed" },
             { "ms", "malayo" },
