@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -85,8 +81,7 @@ public class LocaleNames_es_US extends OpenListResourceBundle {
             { "155", "Europa occidental" },
             { "AC", "Isla de la Ascensi\u00f3n" },
             { "BA", "Bosnia y Herzegovina" },
-            { "CI", "C\u00f4te d\u2019Ivoire" },
-            { "EZ", "zona euro" },
+            { "EH", "Sahara Occidental" },
             { "GG", "Guernsey" },
             { "QO", "Territorios alejados de Ocean\u00eda" },
             { "TA", "Trist\u00e1n de Acu\u00f1a" },
@@ -95,17 +90,17 @@ public class LocaleNames_es_US extends OpenListResourceBundle {
             { "gu", "gurayat\u00ed" },
             { "ht", "criollo haitiano" },
             { "lo", "lao" },
+            { "nd", "ndebele del norte" },
             { "nr", "ndebele meridional" },
             { "rm", "romanche" },
-            { "rn", "kiroundi" },
+            { "se", "sami del norte" },
             { "ss", "siswati" },
-            { "st", "sesotho meridional" },
+            { "st", "sesoto" },
             { "tn", "setchwana" },
-            { "wo", "wolof" },
             { "ace", "acehn\u00e9s" },
             { "alt", "alt\u00e1i meridional" },
             { "arp", "arapaho" },
-            { "bas", "basa" },
+            { "ars", "\u00e1rabe najdi" },
             { "bax", "bamun" },
             { "bho", "bhojpuri" },
             { "bla", "siksika" },
@@ -119,27 +114,26 @@ public class LocaleNames_es_US extends OpenListResourceBundle {
             { "hil", "hiligain\u00f3n" },
             { "hsn", "xiang (China)" },
             { "inh", "ingusetio" },
+            { "kab", "cabilio" },
             { "kbd", "kabardiano" },
             { "krc", "karachay-balkar" },
+            { "lou", "creole de Luisiana" },
+            { "lrc", "lor\u00ed del norte" },
             { "lus", "lushai" },
             { "mga", "irland\u00e9s medieval" },
             { "nso", "sotho septentrional" },
             { "shu", "\u00e1rabe chadiano" },
             { "sma", "sami meridional" },
+            { "smn", "sami de Inari" },
             { "syr", "siriaco" },
             { "tet", "tet\u00fan" },
             { "tyv", "tuviniano" },
+            { "tzm", "tamazight del Marruecos Central" },
             { "xal", "kalmyk" },
-            { "Hanb", "hanb" },
-            { "Mlym", "malay\u00e1lam" },
-            { "Telu", "telegu" },
+            { "Hrkt", "silabarios del japon\u00e9s" },
+            { "Zzzz", "letra desconocida" },
             { "sw_CD", "swahili del Congo" },
-            { "type.ca.roc", "calendario minguo" },
             { "type.nu.gujr", "d\u00edgitos en gujarati" },
-            { "type.nu.knda", "n\u00fameros en kannada" },
-            { "type.nu.laoo", "n\u00fameros en lao" },
-            { "type.co.ducet", "orden de clasificaci\u00f3n de Unicode predeterminado" },
-            { "type.lb.normal", "salto de l\u00ednea normal" },
         };
         return data;
     }
