@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -105,14 +101,17 @@ public class LocaleNames_et extends OpenListResourceBundle {
         final String metaValue_gez = "etioopia";
         final String metaValue_got = "gooti";
         final String metaValue_kpe = "kpelle";
+        final String metaValue_mak = "makassari";
         final String metaValue_men = "mende";
         final String metaValue_new = "nevari";
         final String metaValue_nqo = "nkoo";
         final String metaValue_osa = "oseid\u017ei";
         final String metaValue_peo = "vanap\u00e4rsia";
         final String metaValue_phn = "foiniikia";
+        final String metaValue_rhg = "rohingja";
         final String metaValue_sat = "santali";
         final String metaValue_saz = "saura\u0161tra";
+        final String metaValue_sog = "sogdi";
         final String metaValue_syr = "s\u00fc\u00fcria";
         final String metaValue_uga = "ugariti";
         final String metaValue_vai = "vai";
@@ -177,6 +176,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "kum", "kum\u00f5ki" },
             { "BE", "Belgia" },
             { "gmh", "kesk\u00fclemsaksa" },
+            { "Sogo", "vanasogdi" },
             { "BF", "Burkina Faso" },
             { "BG", "Bulgaaria" },
             { "BH", "Bahrein" },
@@ -201,6 +201,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.ca.persian", "P\u00e4rsia kalender" },
             { "type.nu.hebr", "heebrea numbrid" },
             { "CA", "Kanada" },
+            { "Kits", "kitani v\u00e4ike kiri" },
             { "CC", "Kookossaared" },
             { "mzn", "mazandaraani" },
             { "CD", "Kongo DV" },
@@ -226,6 +227,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "eka", "ekad\u017euki" },
             { "Ahom", "ahomi" },
             { "vls", "l\u00e4\u00e4neflaami" },
+            { "Sogd", metaValue_sog },
             { "DE", "Saksamaa" },
             { "goh", "vana\u00fclemsaksa" },
             { "ace", "at\u0161ehi" },
@@ -273,6 +275,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Hispaania" },
             { "ET", "Etioopia" },
+            { "Vith", "Vithkuqi" },
             { "EU", "Euroopa Liit" },
             { "elx", "eelami" },
             { "type.ca.gregorian", "Gregoriuse kalender" },
@@ -300,7 +303,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "GA", "Gabon" },
             { "tkr", "tsahhi" },
             { "vot", "vadja" },
-            { "GB", "Suurbritannia" },
+            { "GB", "\u00dchendkuningriik" },
             { "pcm", "Nigeeria pid\u017einkeel" },
             { "GD", "Grenada" },
             { "GE", "Gruusia" },
@@ -321,6 +324,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "GT", "Guatemala" },
             { "GU", "Guam" },
             { "pdc", "Pennsylvania saksa" },
+            { "rhg", metaValue_rhg },
             { "GW", "Guinea-Bissau" },
             { "tli", "tlingiti" },
             { "tlh", "klingoni" },
@@ -463,6 +467,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "MQ", "Martinique" },
             { "MR", "Mauritaania" },
             { "MS", "Montserrat" },
+            { "Chrs", "horezmi" },
             { "MT", "Malta" },
             { "cps", "kapisnoni" },
             { "type.m0.ungegn", "transkriptsioon (UNGEGN)" },
@@ -498,7 +503,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "Phnx", metaValue_phn },
             { "NU", "Niue" },
             { "rof", "rombo" },
-            { "tsi", "t\u0161im\u0161i" },
+            { "tsi", "tsim\u0161i" },
             { "NZ", "Uus-Meremaa" },
             { "Merc", "meroe kursiivkiri" },
             { "rom", "mustlaskeel" },
@@ -547,6 +552,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.nu.takr", "taakri numbrid" },
             { "tvl", "tuvalu" },
             { "Tavt", "tai-vieti" },
+            { "Maka", metaValue_mak },
             { "001", "maailm" },
             { "002", "Aafrika" },
             { "njo", "ao" },
@@ -571,6 +577,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "Mand", "mandea" },
             { "SB", "Saalomoni Saared" },
             { "twq", "taswaqi" },
+            { "Tnsa", "tase" },
             { "011", "L\u00e4\u00e4ne-Aafrika" },
             { "SC", "Sei\u0161ellid" },
             { "SD", "Sudaan" },
@@ -685,7 +692,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "VU", "Vanuatu" },
             { "nog", "nogai" },
             { "rwk", "rvaa" },
-            { "non", "vanap\u00f5hjala" },
+            { "non", "vanap\u00f5hja" },
             { "053", "Australaasia" },
             { "%%AREVMDA", "l\u00e4\u00e4nearmeenia" },
             { "054", "Melaneesia" },
@@ -787,6 +794,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.nu.native", "kohalikud numbrid" },
             { "sba", "ngambai" },
             { "Guru", "gurmukhi" },
+            { "type.nu.diak", "divehi numbrid" },
             { "lua", "lulua" },
             { "type.nu.tirh", "tirhuta numbrid" },
             { "type.d0.fwidth", "t\u00e4islaius" },
@@ -818,6 +826,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "scn", "sitsiilia" },
             { "aa", "afari" },
             { "ab", "abhaasi" },
+            { "Aran", "nastaliik" },
             { "bbc", metaValue_bbc },
             { "ae", metaValue_ae },
             { "af", "afrikaani" },
@@ -838,6 +847,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "sdh", "l\u00f5unakurdi" },
             { "ay", "aimara" },
             { "az", "aserbaid\u017eaani" },
+            { "Rohg", metaValue_rhg },
             { "Khoj", "hod\u017eki" },
             { "%%OSOJS", "Oseacco/Osojane murre" },
             { "ba", "ba\u0161kiiri" },
@@ -939,6 +949,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "ga", "iiri" },
             { "Wcho", "vant\u0161o" },
             { "gd", "gaeli" },
+            { "Gong", "G\u016bnj\u0101la gondi" },
             { "gl", "galeegi" },
             { "Gonm", "Masarami gondi" },
             { "gn", "guaranii" },
@@ -998,10 +1009,11 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "mag", "magahi" },
             { "maf", "mafa" },
             { "mai", "maithili" },
+            { "Ougr", "vanauiguuri" },
             { "smn", "Inari saami" },
             { "ka", metaValue_ka },
+            { "mak", metaValue_mak },
             { "bla", "mustjalaindiaani" },
-            { "mak", "makassari" },
             { "wuu", "uu" },
             { "sms", "koltasaami" },
             { "man", "malinke" },
@@ -1041,8 +1053,8 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "type.nu.lana", "tai tham hora numbrid" },
             { "lt", "leedu" },
             { "lu", "Katanga luba" },
+            { "sog", metaValue_sog },
             { "lv", "l\u00e4ti" },
-            { "sog", "sogdi" },
             { "mg", "malagassi" },
             { "mh", "mar\u0161alli" },
             { "type.co.ducet", "Unicode\u2019i sortimise vaikej\u00e4rjestus" },
@@ -1188,6 +1200,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "bua", "burjaadi" },
             { "143", "Kesk-Aasia" },
             { "te", metaValue_te },
+            { "Toto", "toto" },
             { "145", "L\u00e4\u00e4ne-Aasia" },
             { "tg", "tad\u017eiki" },
             { "th", metaValue_th },
@@ -1213,6 +1226,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "%%BISKE", "San Giorgio/Bila murre" },
             { "150", "Euroopa" },
             { "151", "Ida-Euroopa" },
+            { "type.nu.rohg", "rohingja numbrid" },
             { "154", "P\u00f5hja-Euroopa" },
             { "dzg", "daza" },
             { "155", "L\u00e4\u00e4ne-Euroopa" },
@@ -1246,11 +1260,13 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "syc", "vanas\u00fc\u00fcria" },
             { "Osma", "osmani" },
             { "quc", "kit\u0161e" },
-            { "type.nu.gonm", "masaram gondi numbrid" },
+            { "type.nu.gonm", "Masarami gondi numbrid" },
             { "Newa", metaValue_new },
             { "wa", "vallooni" },
             { "gag", "gagauusi" },
             { "syr", metaValue_syr },
+            { "Cpmn", "K\u00fcprose minose" },
+            { "type.nu.gong", "G\u016bnj\u0101la gondi numbrid" },
             { "Grek", metaValue_el },
             { "gan", "kani" },
             { "kiu", "k\u00f5rmand\u017eki" },
@@ -1258,7 +1274,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "Xsux", "sumeri-akadi kiilkiri" },
             { "wo", "volofi" },
             { "zgh", "tamasikti (Maroko)" },
-            { "ar_001", "araabia (t\u00e4nap\u00e4evane)" },
+            { "ar_001", "t\u00e4nap\u00e4eva araabia kirjakeel" },
             { "Cans", "Kanada p\u00f5lisrahvaste \u00fchtlustatud silpkiri" },
             { "gay", "gajo" },
             { "Mong", metaValue_mn },
@@ -1341,6 +1357,7 @@ public class LocaleNames_et extends OpenListResourceBundle {
             { "ilo", "iloko" },
             { "%%VALENCIA", "valentsia" },
             { "Cprt", "K\u00fcprose silpkiri" },
+            { "Diak", "divehi" },
             { "%%BAKU1926", "\u00fchtlustatud t\u00fcrgi-ladina t\u00e4hestik" },
             { "%%IJEKAVSK", "\u0161tokavi ije-line murrak" },
             { "mua", "mundangi" },
