@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -85,10 +81,10 @@ public class LocaleNames_fa extends OpenListResourceBundle {
         final String metaValue_km = "\u062e\u0645\u0631\u06cc";
         final String metaValue_kn = "\u06a9\u0627\u0646\u0627\u0631\u0627";
         final String metaValue_ko = "\u06a9\u0631\u0647\u200c\u0627\u06cc";
+        final String metaValue_la = "\u0644\u0627\u062a\u06cc\u0646";
         final String metaValue_lo = "\u0644\u0627\u0626\u0648\u0633\u06cc";
         final String metaValue_ml = "\u0645\u0627\u0644\u0627\u06cc\u0627\u0644\u0627\u0645\u06cc";
         final String metaValue_mn = "\u0645\u063a\u0648\u0644\u06cc";
-        final String metaValue_or = "\u0627\u0648\u0631\u06cc\u0647\u200c\u0627\u06cc";
         final String metaValue_si = "\u0633\u06cc\u0646\u0647\u0627\u0644\u06cc";
         final String metaValue_ta = "\u062a\u0627\u0645\u06cc\u0644\u06cc";
         final String metaValue_te = "\u062a\u0644\u0648\u06af\u0648\u06cc\u06cc";
@@ -96,7 +92,6 @@ public class LocaleNames_fa extends OpenListResourceBundle {
         final String metaValue_tl = "\u062a\u0627\u06af\u0627\u0644\u0648\u06af\u06cc";
         final String metaValue_ban = "\u0628\u0627\u0644\u06cc\u0627\u06cc\u06cc";
         final String metaValue_bug = "\u0628\u0648\u06af\u06cc\u0627\u06cc\u06cc";
-        final String metaValue_chr = "\u0686\u0631\u0648\u06a9\u06cc\u0627\u06cc\u06cc";
         final String metaValue_cop = "\u0642\u0628\u0637\u06cc";
         final String metaValue_got = "\u06af\u0648\u062a\u06cc";
         final String metaValue_men = "\u0645\u0646\u062f\u0647\u200c\u0627\u06cc";
@@ -106,7 +101,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
         final String metaValue_uga = "\u0627\u0648\u06af\u0627\u0631\u06cc\u062a\u06cc";
         final String metaValue_vai = "\u0648\u06cc\u0627\u06cc\u06cc";
         final Object[][] data = new Object[][] {
-            { "ksh", "\u0631\u06cc\u067e\u0648\u0627\u0631\u06cc" },
+            { "ksh", "\u06a9\u0648\u0644\u0634" },
             { "Ogam", "\u0627\u0648\u06af\u0627\u0645\u06cc" },
             { "mwl", "\u0645\u06cc\u0631\u0627\u0646\u062f\u06cc" },
             { "Zsym", "\u0639\u0644\u0627\u0626\u0645" },
@@ -143,7 +138,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "AT", "\u0627\u062a\u0631\u06cc\u0634" },
             { "AU", "\u0627\u0633\u062a\u0631\u0627\u0644\u06cc\u0627" },
             { "AW", "\u0622\u0631\u0648\u0628\u0627" },
-            { "en_US", "\u0627\u0646\u06af\u0644\u06cc\u0633\u06cc \u0627\u0645\u0631\u06cc\u06a9\u0627" },
+            { "en_US", "\u0627\u0646\u06af\u0644\u06cc\u0633\u06cc \u0622\u0645\u0631\u06cc\u06a9\u0627" },
             { "AX", "\u062c\u0632\u0627\u06cc\u0631 \u0622\u0644\u0627\u0646\u062f" },
             { "AZ", "\u062c\u0645\u0647\u0648\u0631\u06cc \u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646" },
             { "%%AREVELA", "\u0627\u0631\u0645\u0646\u06cc \u0634\u0631\u0642\u06cc" },
@@ -242,7 +237,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "chp", "\u0686\u06cc\u067e\u0647\u200c\u0648\u06cc\u0647\u200c\u0627\u06cc" },
             { "cho", "\u0686\u0648\u06a9\u062a\u0648\u06cc\u06cc" },
             { "type.nu.mathbold", "\u0627\u0631\u0642\u0627\u0645 \u0631\u06cc\u0627\u0636\u06cc \u0633\u06cc\u0627\u0647" },
-            { "chr", metaValue_chr },
+            { "chr", "\u0686\u0631\u0648\u06a9\u06cc" },
             { "ER", "\u0627\u0631\u06cc\u062a\u0631\u0647" },
             { "ES", "\u0627\u0633\u067e\u0627\u0646\u06cc\u0627" },
             { "ET", "\u0627\u062a\u06cc\u0648\u067e\u06cc" },
@@ -264,7 +259,6 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "Taml", metaValue_ta },
             { "FR", "\u0641\u0631\u0627\u0646\u0633\u0647" },
             { "grb", "\u06af\u0631\u06cc\u0628\u0648\u06cc\u06cc" },
-            { "root", "\u0631\u06cc\u0634\u0647" },
             { "type.ca.indian", "\u062a\u0642\u0648\u06cc\u0645 \u0645\u0644\u06cc \u0647\u0646\u062f" },
             { "grc", "\u06cc\u0648\u0646\u0627\u0646\u06cc \u06a9\u0647\u0646" },
             { "GA", "\u06af\u0627\u0628\u0646" },
@@ -290,6 +284,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "GU", "\u06af\u0648\u0627\u0645" },
             { "pdc", "\u0622\u0644\u0645\u0627\u0646\u06cc \u067e\u0646\u0633\u06cc\u0644\u0648\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
             { "GW", "\u06af\u06cc\u0646\u0647\u0654 \u0628\u06cc\u0633\u0627\u0626\u0648" },
+            { "rhg", "\u0631\u0648\u0647\u06cc\u0646\u06af\u06cc\u0627" },
             { "tli", "\u062a\u0644\u06cc\u0646\u200c\u06af\u06cc\u062a\u06cc" },
             { "tlh", "\u06a9\u0644\u06cc\u0646\u06af\u0648\u0646" },
             { "GY", "\u06af\u0648\u06cc\u0627\u0646" },
@@ -384,7 +379,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "akz", "\u0622\u0644\u0627\u0628\u0627\u0645\u0627\u06cc\u06cc" },
             { "lah", "\u0644\u0627\u0647\u0646\u062f\u0627" },
             { "lag", "\u0644\u0627\u0646\u06af\u06cc" },
-            { "Thaa", "\u062a\u0627\u0646\u0647\u200c\u0627\u06cc" },
+            { "Thaa", "\u062a\u0627\u0646\u0627" },
             { "MA", "\u0645\u0631\u0627\u06a9\u0634" },
             { "MC", "\u0645\u0648\u0646\u0627\u06a9\u0648" },
             { "MD", "\u0645\u0648\u0644\u062f\u0627\u0648\u06cc" },
@@ -534,12 +529,12 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "yap", "\u06cc\u0627\u067e\u06cc" },
             { "TA", "\u062a\u0631\u06cc\u0633\u062a\u0627\u0646 \u062f\u0627 \u06a9\u0648\u0646\u0627" },
             { "asa", "\u0622\u0633\u0648" },
-            { "type.ms.ussystem", "\u062f\u0633\u062a\u06af\u0627\u0647 \u0627\u0646\u062f\u0627\u0632\u0647\u200c\u06af\u06cc\u0631\u06cc \u0627\u0645\u0631\u06cc\u06a9\u0627\u06cc\u06cc" },
+            { "type.ms.ussystem", "\u0633\u06cc\u0633\u062a\u0645 \u0627\u0646\u062f\u0627\u0632\u0647\u200c\u06af\u06cc\u0631\u06cc \u0627\u0645\u0631\u06cc\u06a9\u0627\u06cc\u06cc" },
             { "021", "\u0634\u0645\u0627\u0644 \u0627\u0645\u0631\u06cc\u06a9\u0627" },
             { "TC", "\u062c\u0632\u0627\u06cc\u0631 \u062a\u0648\u0631\u06a9\u0633 \u0648 \u06a9\u0627\u06cc\u06a9\u0648\u0633" },
             { "yav", "\u06cc\u0627\u0646\u06af\u0628\u0646\u06cc" },
             { "TD", "\u0686\u0627\u062f" },
-            { "TF", "\u0633\u0631\u0632\u0645\u06cc\u0646\u200c\u0647\u0627\u06cc \u062c\u0646\u0648\u0628 \u0641\u0631\u0627\u0646\u0633\u0647" },
+            { "TF", "\u0633\u0631\u0632\u0645\u06cc\u0646\u200c\u0647\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc \u0641\u0631\u0627\u0646\u0633\u0647" },
             { "TG", "\u062a\u0648\u06af\u0648" },
             { "TH", "\u062a\u0627\u06cc\u0644\u0646\u062f" },
             { "TJ", "\u062a\u0627\u062c\u06cc\u06a9\u0633\u062a\u0627\u0646" },
@@ -575,7 +570,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "UM", "\u062c\u0632\u0627\u06cc\u0631 \u062f\u0648\u0631\u0627\u0641\u062a\u0627\u062f\u0647\u0654 \u0627\u06cc\u0627\u0644\u0627\u062a \u0645\u062a\u062d\u062f\u0647" },
             { "UN", "\u0633\u0627\u0632\u0645\u0627\u0646 \u0645\u0644\u0644 \u0645\u062a\u062d\u062f" },
             { "US", "\u0627\u06cc\u0627\u0644\u0627\u062a \u0645\u062a\u062d\u062f\u0647" },
-            { "haw", "\u0647\u0627\u0648\u0627\u0626\u06cc\u0627\u06cc\u06cc" },
+            { "haw", "\u0647\u0627\u0648\u0627\u06cc\u06cc" },
             { "type.co.gb2312han", "\u062a\u0631\u062a\u06cc\u0628 \u0686\u06cc\u0646\u06cc \u0633\u0627\u062f\u0647\u200c\u0634\u062f\u0647 - GB2312" },
             { "UY", "\u0627\u0631\u0648\u06af\u0648\u0626\u0647" },
             { "prg", "\u067e\u0631\u0648\u0633\u06cc" },
@@ -714,7 +709,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "an", "\u0622\u0631\u0627\u06af\u0648\u0646\u06cc" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
-            { "Hrkt", "\u0633\u06cc\u0644\u0627\u0628\u06cc\u200c\u0647\u0627\u06cc \u0698\u0627\u067e\u0646\u06cc" },
+            { "Hrkt", "\u0647\u062c\u0627\u0646\u06af\u0627\u0631\u06cc \u0698\u0627\u067e\u0646\u06cc" },
             { "as", "\u0622\u0633\u0627\u0645\u06cc" },
             { "Lina", "\u062e\u0637\u06cc \u0627\u0644\u0641" },
             { "av", "\u0622\u0648\u0627\u0631\u06cc" },
@@ -745,7 +740,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "ch", "\u0686\u0627\u0645\u0648\u0631\u0648\u06cc\u06cc" },
             { "%%REVISED", "\u0631\u0633\u0645\u200c\u0627\u0644\u062e\u0637 \u062a\u062c\u062f\u06cc\u062f\u0646\u0638\u0631\u0634\u062f\u0647" },
             { "co", "\u06a9\u0648\u0631\u0633\u06cc" },
-            { "Orya", metaValue_or },
+            { "Orya", "\u0627\u0648\u062f\u06cc\u0647" },
             { "cr", "\u06a9\u0631\u06cc\u0627\u06cc\u06cc" },
             { "cs", "\u0686\u06a9\u06cc" },
             { "cu", "\u0627\u0633\u0644\u0627\u0648\u06cc \u06a9\u0644\u06cc\u0633\u0627\u06cc\u06cc" },
@@ -807,7 +802,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "umb", "\u0627\u0645\u0628\u0648\u0646\u062f\u0648\u06cc\u06cc" },
             { "fr", "\u0641\u0631\u0627\u0646\u0633\u0648\u06cc" },
             { "sid", "\u0633\u06cc\u062f\u0627\u0645\u0648\u06cc\u06cc" },
-            { "fy", "\u0641\u0631\u06cc\u0632\u06cc \u063a\u0631\u0628\u06cc" },
+            { "fy", "\u0641\u0631\u06cc\u0633\u06cc \u063a\u0631\u0628\u06cc" },
             { "ga", "\u0627\u06cc\u0631\u0644\u0646\u062f\u06cc" },
             { "gd", "\u06af\u06cc\u0644\u06cc \u0627\u0633\u06a9\u0627\u062a\u0644\u0646\u062f\u06cc" },
             { "gl", "\u06af\u0627\u0644\u06cc\u0633\u06cc\u0627\u06cc\u06cc" },
@@ -818,7 +813,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "gu", metaValue_gu },
             { "type.ca.islamic-tbla", "\u062a\u0642\u0648\u06cc\u0645 \u0647\u062c\u0631\u06cc \u0642\u0645\u0631\u06cc \u062c\u062f\u0648\u0644\u06cc \u0646\u062c\u0648\u0645\u06cc" },
             { "gv", "\u0645\u0627\u0646\u06cc" },
-            { "ha", "\u0647\u0648\u0633\u06cc\u0627\u06cc\u06cc" },
+            { "ha", "\u0647\u0648\u0633\u0627\u06cc\u06cc" },
             { "he", metaValue_he },
             { "hi", "\u0647\u0646\u062f\u06cc" },
             { "hup", "\u0647\u0648\u067e\u0627" },
@@ -832,7 +827,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "hz", "\u0647\u0631\u06cc\u0631\u0648\u06cc\u06cc" },
             { "frc", "\u0641\u0631\u0627\u0646\u0633\u0648\u06cc \u06a9\u0627\u062f\u06cc\u0646" },
             { "%%FONIPA", "\u0641\u0648\u0646\u062a\u06cc\u06a9 IPA" },
-            { "ia", "\u0645\u06cc\u0627\u0646\u200c\u0632\u0628\u0627\u0646" },
+            { "ia", "\u0627\u06cc\u0646\u062a\u0631\u0644\u06cc\u0646\u06af\u0648\u0627" },
             { "Jamo", "\u062c\u0627\u0645\u0648" },
             { "id", "\u0627\u0646\u062f\u0648\u0646\u0632\u06cc\u0627\u06cc\u06cc" },
             { "type.nu.tibt", "\u0627\u0631\u0642\u0627\u0645 \u062a\u0628\u062a\u06cc" },
@@ -883,10 +878,10 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "Avst", metaValue_ae },
             { "ku", "\u06a9\u0631\u062f\u06cc" },
             { "kv", "\u06a9\u0648\u0645\u06cc\u0627\u06cc\u06cc" },
-            { "kw", "\u06a9\u0631\u0646\u0648\u0627\u0644\u06cc" },
+            { "kw", "\u06a9\u0648\u0631\u0646\u06cc" },
             { "ky", "\u0642\u0631\u0642\u06cc\u0632\u06cc" },
             { "snk", "\u0633\u0648\u0646\u06cc\u0646\u06a9\u0647\u200c\u0627\u06cc" },
-            { "la", "\u0644\u0627\u062a\u06cc\u0646" },
+            { "la", metaValue_la },
             { "lb", "\u0644\u0648\u06af\u0632\u0627\u0645\u0628\u0648\u0631\u06af\u06cc" },
             { "type.nu.mlym", "\u0627\u0631\u0642\u0627\u0645 \u0645\u0627\u0644\u0627\u06cc\u0627\u0644\u0627\u0645\u06cc" },
             { "lg", "\u06af\u0627\u0646\u062f\u0627\u06cc\u06cc" },
@@ -895,16 +890,16 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "ln", "\u0644\u06cc\u0646\u06af\u0627\u0644\u0627" },
             { "fur", "\u0641\u0631\u06cc\u0648\u0644\u06cc\u0627\u06cc\u06cc" },
             { "lo", metaValue_lo },
-            { "type.ms.uksystem", "\u062f\u0633\u062a\u06af\u0627\u0647 \u0627\u0646\u062f\u0627\u0632\u0647\u200c\u06af\u06cc\u0631\u06cc \u0628\u0631\u06cc\u062a\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
+            { "type.ms.uksystem", "\u0633\u06cc\u0633\u062a\u0645 \u0627\u0646\u062f\u0627\u0632\u0647\u200c\u06af\u06cc\u0631\u06cc \u0627\u0646\u06af\u0644\u06cc\u0633\u06cc" },
             { "lt", "\u0644\u06cc\u062a\u0648\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
             { "lu", "\u0644\u0648\u0628\u0627\u06cc\u06cc\u2010\u06a9\u0627\u062a\u0627\u0646\u06af\u0627" },
             { "lv", "\u0644\u062a\u0648\u0646\u06cc\u0627\u06cc\u06cc" },
             { "sog", "\u0633\u063a\u062f\u06cc" },
             { "ListCompositionPattern", "{0}\u060c {1}" },
-            { "mg", "\u0645\u0627\u0644\u0627\u06af\u0627\u0633\u06cc\u0627\u06cc\u06cc" },
+            { "mg", "\u0645\u0627\u0644\u0627\u06af\u0627\u0633\u06cc" },
             { "mh", "\u0645\u0627\u0631\u0634\u0627\u0644\u06cc" },
             { "type.co.ducet", "\u062a\u0631\u062a\u06cc\u0628 \u067e\u06cc\u0634\u200c\u0641\u0631\u0636 \u06cc\u0648\u0646\u06cc\u200c\u06a9\u062f" },
-            { "mi", "\u0645\u0627\u0626\u0648\u0631\u06cc\u0627\u06cc\u06cc" },
+            { "mi", "\u0645\u0627\u0626\u0648\u0631\u06cc" },
             { "mk", "\u0645\u0642\u062f\u0648\u0646\u06cc" },
             { "ml", metaValue_ml },
             { "mn", metaValue_mn },
@@ -942,7 +937,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "type.nu.armn", "\u0627\u0639\u062f\u0627\u062f \u0627\u0631\u0645\u0646\u06cc" },
             { "om", "\u0627\u0648\u0631\u0648\u0645\u0648\u06cc\u06cc" },
             { "kaw", "\u06a9\u0627\u0648\u06cc\u0627\u06cc\u06cc" },
-            { "or", metaValue_or },
+            { "or", "\u0627\u0648\u0631\u06cc\u0647\u200c\u0627\u06cc" },
             { "os", "\u0622\u0633\u06cc" },
             { "kbd", "\u06a9\u0627\u0628\u0627\u0631\u062f\u06cc\u0646\u06cc" },
             { "mfe", "\u0645\u0648\u0631\u06cc\u0633\u06cc\u0646" },
@@ -985,7 +980,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "key.cu", "\u0648\u0627\u062d\u062f \u067e\u0648\u0644" },
             { "ro", "\u0631\u0648\u0645\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
             { "%%SAAHO", "\u0633\u0627\u0647\u0648\u06cc\u06cc" },
-            { "type.nu.orya", "\u0627\u0631\u0642\u0627\u0645 \u0627\u0648\u0631\u06cc\u0647\u200c\u0627\u06cc" },
+            { "type.nu.orya", "\u0627\u0631\u0642\u0627\u0645 \u0627\u0648\u062f\u06cc\u0647" },
             { "type.nu.hanidec", "\u0627\u0639\u062f\u0627\u062f \u062f\u0647\u062f\u0647\u06cc \u0686\u06cc\u0646\u06cc" },
             { "ru", "\u0631\u0648\u0633\u06cc" },
             { "rw", "\u06a9\u06cc\u0646\u06cc\u0627\u0631\u0648\u0627\u0646\u062f\u0627\u06cc\u06cc" },
@@ -1014,7 +1009,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "ss", "\u0633\u0648\u0627\u0632\u06cc\u0627\u06cc\u06cc" },
             { "type.cf.account", "\u0642\u0627\u0644\u0628 \u062d\u0633\u0627\u0628\u062f\u0627\u0631\u06cc \u0648\u0627\u062d\u062f \u067e\u0648\u0644" },
             { "Java", metaValue_jv },
-            { "st", "\u0633\u0648\u062a\u0648\u06cc\u06cc \u062c\u0646\u0648\u0628\u06cc" },
+            { "st", "\u0633\u0648\u062a\u0648\u06cc \u062c\u0646\u0648\u0628\u06cc" },
             { "su", "\u0633\u0648\u0646\u062f\u0627\u06cc\u06cc" },
             { "sv", "\u0633\u0648\u0626\u062f\u06cc" },
             { "sw", "\u0633\u0648\u0627\u062d\u06cc\u0644\u06cc" },
@@ -1096,8 +1091,8 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "szl", "\u0633\u06cc\u0644\u0632\u06cc\u0627\u06cc\u06cc" },
             { "Hluw", "\u0647\u06cc\u0631\u0648\u06af\u0644\u06cc\u0641 \u0622\u0646\u0627\u062a\u0648\u0644\u06cc" },
             { "gba", "\u06af\u0628\u0627\u06cc\u0627\u06cc\u06cc" },
-            { "mni", "\u0645\u06cc\u062a\u0647\u200c\u0627\u06cc" },
-            { "Latn", "\u0644\u0627\u062a\u06cc\u0646\u06cc" },
+            { "mni", "\u0645\u0627\u0646\u06cc\u067e\u0648\u0631\u06cc" },
+            { "Latn", metaValue_la },
             { "Latg", "\u0644\u0627\u062a\u06cc\u0646\u06cc \u06af\u06cc\u0644\u06cc" },
             { "type.nu.hans", "\u0627\u0639\u062f\u0627\u062f \u0686\u06cc\u0646\u06cc \u0633\u0627\u062f\u0647\u200c\u0634\u062f\u0647" },
             { "type.nu.hant", "\u0627\u0639\u062f\u0627\u062f \u0686\u06cc\u0646\u06cc \u0633\u0646\u062a\u06cc" },
@@ -1163,7 +1158,7 @@ public class LocaleNames_fa extends OpenListResourceBundle {
             { "mus", "\u06a9\u0631\u06cc\u06a9\u06cc" },
             { "Glag", "\u06af\u0644\u0627\u06af\u0648\u0644\u06cc\u062a\u06cc" },
             { "gil", "\u06af\u06cc\u0644\u0628\u0631\u062a\u06cc" },
-            { "Cher", metaValue_chr },
+            { "Cher", "\u0686\u0631\u0648\u06a9\u06cc\u0627\u06cc\u06cc" },
             { "car", "\u06a9\u0627\u0631\u06cc\u0628\u06cc" },
             { "type.nu.tamldec", "\u0627\u0631\u0642\u0627\u0645 \u062a\u0627\u0645\u06cc\u0644\u06cc" },
             { "krc", "\u0642\u0631\u0647\u200c\u0686\u0627\u06cc\u06cc\u2010\u0628\u0627\u0644\u06a9\u0627\u0631\u06cc" },
