@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -328,7 +324,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "TD", "\u0427\u0430\u0434" },
             { "TF", "\u0424\u0440\u0430\u043d\u0446\u0438\u044f\u043d\u044b\u04a3 \u043e\u04a3\u0442\u04af\u0441\u0442\u0456\u043a \u0430\u0439\u043c\u0430\u049b\u0442\u0430\u0440\u044b" },
             { "TG", "\u0422\u043e\u0433\u043e" },
-            { "TH", "\u0422\u0430\u0439\u043b\u0430\u043d\u0434" },
+            { "TH", "\u0422\u0430\u0438\u043b\u0430\u043d\u0434" },
             { "TJ", "\u0422\u04d9\u0436\u0456\u043a\u0441\u0442\u0430\u043d" },
             { "TK", "\u0422\u043e\u043a\u0435\u043b\u0430\u0443" },
             { "TL", "\u0422\u0438\u043c\u043e\u0440-\u041b\u0435\u0441\u0442\u0435" },
@@ -543,7 +539,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "ace", "\u0430\u0447\u0435\u0445 \u0442\u0456\u043b\u0456" },
             { "ada", "\u0430\u0434\u0430\u043d\u0433\u043c\u0435 \u0442\u0456\u043b\u0456" },
             { "ady", "\u0430\u0434\u044b\u0433\u0435\u0439 \u0442\u0456\u043b\u0456" },
-            { "agq", "\u0430\u0433\u0445\u0435\u043c \u0442\u0456\u043b\u0456" },
+            { "agq", "\u0430\u0433\u0435\u043c \u0442\u0456\u043b\u0456" },
             { "ain", "\u0430\u0439\u043d\u0443 \u0442\u0456\u043b\u0456" },
             { "ale", "\u0430\u043b\u0435\u0443\u0442 \u0442\u0456\u043b\u0456" },
             { "alt", "\u043e\u04a3\u0442\u04af\u0441\u0442\u0456\u043a \u0430\u043b\u0442\u0430\u0439 \u0442\u0456\u043b\u0456" },
@@ -579,6 +575,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "dav", "\u0442\u0430\u0438\u0442\u0430 \u0442\u0456\u043b\u0456" },
             { "dgr", "\u0434\u043e\u0433\u0440\u0438\u0431 \u0442\u0456\u043b\u0456" },
             { "dje", "\u0437\u0430\u0440\u043c\u0430 \u0442\u0456\u043b\u0456" },
+            { "doi", "\u0414\u043e\u0433\u0440\u0438" },
             { "dsb", "\u0442\u04e9\u043c\u0435\u043d\u0433\u0456 \u043b\u0443\u0436\u0438\u0446\u0430 \u0442\u0456\u043b\u0456" },
             { "dua", "\u0434\u0443\u0430\u043b\u0430 \u0442\u0456\u043b\u0456" },
             { "dyo", "\u0434\u0438\u043e\u043b\u0430 \u0442\u0456\u043b\u0456" },
@@ -689,6 +686,7 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "quc", "\u043a\u0438\u0447\u0435 \u0442\u0456\u043b\u0456" },
             { "rap", "\u0440\u0430\u043f\u0430\u043d\u0443\u0439 \u0442\u0456\u043b\u0456" },
             { "rar", "\u0440\u0430\u0440\u043e\u0442\u043e\u043d\u0433\u0430\u043d \u0442\u0456\u043b\u0456" },
+            { "rhg", "\u0440\u043e\u0445\u0438\u043d\u0434\u0436\u0430" },
             { "rof", "\u0440\u043e\u043c\u0431\u043e \u0442\u0456\u043b\u0456" },
             { "rup", "\u0430\u0440\u0443\u043c\u044b\u043d \u0442\u0456\u043b\u0456" },
             { "rwk", "\u0440\u0443\u0430 \u0442\u0456\u043b\u0456" },
@@ -789,7 +787,6 @@ public class LocaleNames_kk extends OpenListResourceBundle {
             { "Zxxx", "\u0436\u0430\u0437\u0443\u0441\u044b\u0437" },
             { "Zyyy", "\u0436\u0430\u043b\u043f\u044b" },
             { "Zzzz", "\u0431\u0435\u043b\u0433\u0456\u0441\u0456\u0437 \u0436\u0430\u0437\u0443" },
-            { "root", "\u0430\u0442\u0430 \u0442\u0456\u043b" },
             { "de_AT", "\u0430\u0432\u0441\u0442\u0440\u0438\u044f\u043b\u044b\u049b \u043d\u0435\u043c\u0456\u0441 \u0442\u0456\u043b\u0456" },
             { "de_CH", "\u0448\u0432\u0435\u0439\u0446\u0430\u0440\u0438\u044f\u043b\u044b\u049b \u04d9\u0434\u0435\u0431\u0438 \u043d\u0435\u043c\u0456\u0441 \u0442\u0456\u043b\u0456" },
             { "en_AU", "\u0430\u0432\u0441\u0442\u0440\u0430\u043b\u0438\u044f\u043b\u044b\u049b \u0430\u0493\u044b\u043b\u0448\u044b\u043d \u0442\u0456\u043b\u0456" },
