@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -259,7 +255,6 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "Kpel", "\u0ec0\u0e9b\u0ea5\u0ec0\u0ea5" },
             { "tkl", metaValue_TK },
             { "grb", "\u0e81\u0ea3\u0eb5\u0ec2\u0e9a" },
-            { "root", "\u0ea5\u0eb9\u0e94" },
             { "type.ca.indian", "\u0e9b\u0eb0\u0e95\u0eb4\u0e97\u0eb4\u0e99\u0ec1\u0eab\u0ec8\u0e87\u0e8a\u0eb2\u0e94\u0ead\u0eb4\u0e99\u0ec0\u0e94\u0e8d" },
             { "grc", "\u0ec1\u0ead\u0e99\u0e8a\u0ebd\u0e99\u0e81\u0ea3\u0eb5\u0e81" },
             { "GA", "\u0e81\u0eb2\u0e9a\u0ead\u0e99" },
@@ -285,6 +280,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "GT", "\u0e81\u0ebb\u0ea7\u0ec0\u0e97\u0ea1\u0eb2\u0ea5\u0eb2" },
             { "GU", "\u0e81\u0ea7\u0eb2\u0ea1" },
             { "GW", "\u0e81\u0eb4\u0e99\u0eb5-\u0e9a\u0eb4\u0eaa\u0ec0\u0e8a\u0ebb\u0eb2" },
+            { "rhg", "\u0ec2\u0ea3\u0eae\u0eb4\u0e99\u0ea2\u0eb2" },
             { "tli", "\u0e97\u0ea5\u0eb5\u0e87\u0e81\u0eb4\u0e94" },
             { "tlh", "\u0e84\u0ea3\u0eb4\u0e87\u0e81\u0ead\u0e99" },
             { "Talu", "\u0ec4\u0e97\u0ea5\u0eb7\u0ec9\u0ec3\u0edd\u0ec8" },
@@ -466,7 +462,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "PM", "\u0ec0\u0e8a\u0e99 \u0e9b\u0eb5\u0ec1\u0ead \u0ea1\u0eb4\u0ec0\u0e81\u0ea7\u0ea5\u0ead\u0e99" },
             { "PN", "\u0edd\u0eb9\u0ec8\u0ec0\u0e81\u0eb2\u0eb0\u0e9e\u0eb4\u0e94\u0ec1\u0e84\u0e99" },
             { "PR", "\u0ec0\u0e9e\u0eb7\u0ead\u0ec2\u0e95 \u0ea3\u0eb4\u0ec2\u0e81" },
-            { "PS", "\u0e94\u0eb4\u0e99\u0ec1\u0e94\u0e99 \u0e9b\u0eb2\u0ec0\u0ea5\u0eaa\u0e95\u0eb4\u0e99\u0ebd\u0e99" },
+            { "PS", "\u0e94\u0eb4\u0e99\u0ec1\u0e94\u0e99\u0e9b\u0eb2\u0ec0\u0ea5\u0e94\u0eaa\u0eb0\u0e95\u0eb4\u0e99" },
             { "Bali", "\u0e9a\u0eb2\u0ea5\u0eb5" },
             { "PT", "\u0e9e\u0ead\u0ea5\u0e97\u0eb9\u0ec2\u0e81" },
             { "PW", "\u0e9b\u0eb2\u0ea5\u0eb2\u0ea7" },
@@ -855,7 +851,7 @@ public class LocaleNames_lo extends OpenListResourceBundle {
             { "type.nu.tibt", "\u0e95\u0ebb\u0ea7\u0ec0\u0ea5\u0e81\u0e97\u0eb4\u0ec0\u0e9a\u0e94" },
             { "ie", "\u0ead\u0eb4\u0e99\u0ec0\u0e95\u0eb5\u0ea5\u0eb4\u0e87\u0e81\u0ea3\u0eb5" },
             { "ig", "\u0ead\u0eb4\u0e81\u0ec2\u0e9a" },
-            { "ii", "\u0ec0\u0e8a\u0eaa\u0ea7\u0e8d\u0ea2\u0eb5" },
+            { "ii", "\u0ec0\u0eaa\u0eaa\u0ea7\u0e99 \u0ead\u0eb5" },
             { "frm", "\u0e9f\u0eae\u0eb1\u0ec8\u0e87\u0ec0\u0eaa\u0e94\u0e81\u0eb2\u0e87" },
             { "%%RUMGR", "\u0ea3\u0eb3\u0e81\u0ea3\u0ecc" },
             { "ik", "\u0ead\u0eb4\u0e99\u0e99\u0eb9\u0e9b\u0ebd\u0e81" },
