@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -279,7 +275,6 @@ public class LocaleNames_lt extends OpenListResourceBundle {
             { "pcd", "pikard\u0173" },
             { "tkl", metaValue_TK },
             { "grb", "grebo" },
-            { "root", "r\u016bt" },
             { "type.ca.indian", "nacionalinis ind\u0173 kalendorius" },
             { "rgn", "ital\u0173 kalbos Romanijos tarm\u0117" },
             { "grc", "senov\u0117s graik\u0173" },
@@ -308,6 +303,7 @@ public class LocaleNames_lt extends OpenListResourceBundle {
             { "GU", "Guamas" },
             { "pdc", "Pensilvanijos vokie\u010di\u0173" },
             { "GW", "Bisau Gvin\u0117ja" },
+            { "rhg", "rochind\u017ea" },
             { "tli", "tlingit\u0173" },
             { "tlh", "klingon\u0173" },
             { "Talu", "naujasis Tailando lue" },
@@ -595,7 +591,7 @@ public class LocaleNames_lt extends OpenListResourceBundle {
             { "ary", "Maroko arab\u0173" },
             { "yap", "japez\u0173" },
             { "rtm", "rotuman\u0173" },
-            { "TA", "Tristanas da Kunja" },
+            { "TA", "Tristano da Kunjos" },
             { "asa", "asu" },
             { "type.ms.ussystem", "amerikieti\u0161ka mat\u0173 sistema" },
             { "021", "\u0160iaurin\u0117 Amerika" },
