@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -134,7 +130,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "Prti", "\u092a\u093f\u0906\u0930\u091f\u0940" },
             { "AS", "\u0905\u092e\u0947\u0930\u093f\u0915\u0940 \u0938\u092e\u094b\u0906" },
             { "AT", "\u0905\u0937\u094d\u091f\u094d\u0930\u093f\u092f\u093e" },
-            { "AU", "\u0905\u0937\u094d\u091f\u094d\u0930\u0947\u0932\u093f\u092f\u093e" },
+            { "AU", "\u0905\u0938\u094d\u091f\u094d\u0930\u0947\u0932\u093f\u092f\u093e" },
             { "AW", "\u0905\u0930\u0941\u092c\u093e" },
             { "en_US", "\u0905\u092e\u0947\u0930\u093f\u0915\u0940 \u0905\u0919\u094d\u0917\u094d\u0930\u0947\u091c\u0940" },
             { "AX", "\u0905\u0932\u093e\u0928\u094d\u0921 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
@@ -256,7 +252,6 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "FR", "\u092b\u094d\u0930\u093e\u0928\u094d\u0938" },
             { "pcd", "\u092a\u093f\u0915\u093e\u0930\u094d\u0921" },
             { "grb", "\u0917\u094d\u0930\u0947\u092c\u094b" },
-            { "root", "\u0930\u0941\u091f" },
             { "type.ca.indian", "\u092d\u093e\u0930\u0924\u0940\u092f \u0930\u093e\u0937\u094d\u091f\u094d\u0930\u093f\u092f \u092a\u093e\u0924\u094d\u0930\u094b" },
             { "grc", "\u092a\u0941\u0930\u093e\u0924\u0928 \u0917\u094d\u0930\u093f\u0915" },
             { "GA", "\u0917\u093e\u0935\u094b\u0928" },
@@ -282,6 +277,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "GU", "\u0917\u0941\u0935\u093e\u092e" },
             { "pdc", "\u092a\u0947\u0928\u094d\u0938\u093f\u0932\u092d\u093e\u0928\u093f\u092f\u093e\u0932\u0940 \u091c\u0930\u094d\u092e\u0928" },
             { "GW", "\u0917\u093f\u0928\u0940-\u092c\u093f\u0938\u093e\u0909" },
+            { "rhg", "\u0930\u094b\u0939\u093f\u0919\u094d\u0917\u094d\u092f\u093e" },
             { "tlh", "\u0915\u094d\u0932\u093f\u0919\u094d\u0917\u0928" },
             { "Talu", "\u0928\u094d\u092f\u0942 \u091f\u093e\u0907 \u0932\u0941\u0907" },
             { "GY", "\u0917\u0941\u092f\u093e\u0928\u093e" },
@@ -392,7 +388,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "MM", "\u092e\u094d\u092f\u093e\u0928\u094d\u092e\u093e\u0930 (\u092c\u0930\u094d\u092e\u093e)" },
             { "MN", "\u092e\u0919\u094d\u0917\u094b\u0932\u093f\u092f\u093e" },
             { "new", "\u0928\u0947\u0935\u093e\u0930\u0940" },
-            { "MO", "(\u092e\u0915\u093e\u0909 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0935\u093f\u0936\u0947\u0937 \u092a\u094d\u0930\u0936\u093e\u0938\u0928\u093f\u0915 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
+            { "MO", "\u092e\u0915\u093e\u0909 \u091a\u093f\u0928\u093f\u092f\u093e\u0901 \u0935\u093f\u0936\u0947\u0937 \u092a\u094d\u0930\u0936\u093e\u0938\u0928\u093f\u0915 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "aln", "\u0918\u0947\u0917 \u0905\u0932\u094d\u092c\u093e\u0928\u093f\u092f\u093e\u0932\u0940" },
             { "MP", "\u0909\u0924\u094d\u0924\u0930\u0940 \u092e\u093e\u0930\u093f\u0906\u0928\u093e \u091f\u093e\u092a\u0941" },
             { "MQ", "\u092e\u093e\u0930\u094d\u091f\u093f\u0928\u093f\u0915" },
@@ -451,7 +447,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "PN", "\u092a\u093f\u091f\u0915\u093e\u0907\u0930\u094d\u0928 \u091f\u093e\u092a\u0941\u0939\u0930\u0941" },
             { "PR", "\u092a\u0941\u090f\u0930\u094d\u091f\u094b \u0930\u093f\u0915\u094b" },
             { "Bali", metaValue_ban },
-            { "PS", "\u092a\u094d\u092f\u093e\u0932\u0947\u0938\u094d\u091f\u0928\u0940 \u092d\u0942-\u092d\u093e\u0917\u0939\u0930\u0941" },
+            { "PS", "\u092a\u094d\u092f\u093e\u0932\u0947\u0938\u094d\u091f\u093f\u0928\u0940 \u092d\u0942-\u092d\u093e\u0917\u0939\u0930\u0942" },
             { "PT", "\u092a\u094b\u0930\u094d\u091a\u0941\u0917\u0932" },
             { "PW", "\u092a\u0932\u093e\u0909" },
             { "nia", "\u0928\u093f\u092f\u093e\u0938" },
@@ -633,7 +629,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "ZZ", "\u0905\u091c\u094d\u091e\u093e\u0924 \u0915\u094d\u0937\u0947\u0924\u094d\u0930" },
             { "Runr", "\u0930\u0942\u0928\u093f\u0915" },
             { "type.ms.metric", "\u092e\u0947\u091f\u094d\u0930\u093f\u0915 \u092a\u094d\u0930\u0923\u093e\u0932\u0940" },
-            { "type.ca.iso8601", "ISO-8601 Calendar" },
+            { "type.ca.iso8601", "ISO-8601 \u092a\u093e\u0924\u094d\u0930\u094b" },
             { "lol", "\u092e\u094b\u0919\u094d\u0917\u094b" },
             { "nso", "\u0909\u0924\u094d\u0924\u0930\u0940 \u0938\u094b\u0925\u094b" },
             { "type.nu.telu", "\u0924\u0947\u0932\u0947\u0917\u0941 \u0905\u0919\u094d\u0915\u0939\u0930\u0942" },
@@ -929,7 +925,7 @@ public class LocaleNames_ne extends OpenListResourceBundle {
             { "kaw", "\u0915\u093e\u0935\u0940" },
             { "dtp", "\u0915\u0947\u0928\u094d\u0926\u094d\u0930\u0940\u092f \u0926\u0941\u0938\u0941\u0928" },
             { "or", "\u0909\u0921\u093f\u092f\u093e" },
-            { "os", "\u0905\u094b\u0938\u094d\u0938\u0947\u091f\u093f\u0915" },
+            { "os", "\u0913\u0938\u094d\u0938\u0947\u091f\u093f\u0915" },
             { "bpy", "\u0935\u093f\u0937\u094d\u0923\u0941\u092a\u094d\u0930\u093f\u092f\u093e" },
             { "kbd", "\u0915\u093e\u092c\u093e\u0930\u094d\u0926\u093f\u092f\u093e\u0932\u0940" },
             { "mfe", "\u092e\u094b\u0930\u093f\u0938\u0947\u0928" },
