@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -250,7 +246,6 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "FR", "\u0b2b\u0b4d\u0b30\u0b3e\u0b28\u0b4d\u0b38" },
             { "tkl", metaValue_TK },
             { "grb", "\u0b17\u0b4d\u0b30\u0b47\u0b2c\u0b4b" },
-            { "root", "\u0b30\u0b4b\u0b1f\u0b4d" },
             { "grc", "\u0b2a\u0b4d\u0b30\u0b3e\u0b1a\u0b40\u0b28\u0b4d \u0b5f\u0b41\u0b28\u0b3e\u0b28\u0b40" },
             { "GA", "\u0b17\u0b3e\u0b2c\u0b4b\u0b28\u0b4d" },
             { "vot", "\u0b2d\u0b4b\u0b1f\u0b3f\u0b15\u0b4d" },
@@ -275,6 +270,7 @@ public class LocaleNames_or extends OpenListResourceBundle {
             { "GT", "\u0b17\u0b41\u0b0f\u0b24\u0b2e\u0b3e\u0b32\u0b3e" },
             { "GU", "\u0b17\u0b41\u0b06\u0b2e\u0b4d" },
             { "GW", "\u0b17\u0b41\u0b07\u0b28\u0b3f\u0b06-\u0b2c\u0b3f\u0b38\u0b3e\u0b09" },
+            { "rhg", "\u0b30\u0b4b\u0b39\u0b3f\u0b19\u0b4d\u0b17\u0b4d\u0b5f\u0b3e" },
             { "tli", "\u0b24\u0b4d\u0b32\u0b3f\u0b19\u0b4d\u0b17\u0b3f\u0b1f\u0b4d" },
             { "tlh", "\u0b15\u0b4d\u0b32\u0b3f\u0b19\u0b4d\u0b17\u0b28\u0b4d" },
             { "Talu", "\u0b28\u0b42\u0b24\u0b28 \u0b24\u0b3e\u0b07 \u0b32\u0b41\u0b0f" },
