@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -94,6 +90,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
         final String metaValue_th = "tailandais";
         final String metaValue_tl = "tagalog";
         final String metaValue_ban = "balinais";
+        final String metaValue_ccp = "chakma";
         final String metaValue_chr = "cherokee";
         final String metaValue_cop = "coptic";
         final String metaValue_got = "gotic";
@@ -104,19 +101,24 @@ public class LocaleNames_rm extends OpenListResourceBundle {
         final String metaValue_uga = "ugaritic";
         final String metaValue_zbl = "simbols da Bliss";
         final Object[][] data = new Object[][] {
+            { "ksh", "colognais" },
             { "Ogam", "ogham" },
             { "mwl", "mirandais" },
             { "Zsym", "simbols" },
             { "cch", "atsam" },
             { "mwr", "marwari" },
             { "Tagb", "tagbanwa" },
+            { "Zsye", "emojis" },
             { "%%NJIVA", "dialect da Gniva" },
+            { "ccp", metaValue_ccp },
             { "egy", "egipzian vegl" },
             { "raj", "rajasthani" },
             { "Phag", "phags-pa" },
             { "tem", "temne" },
+            { "teo", "teso" },
             { "rap", "rapanui" },
             { "ter", "tereno" },
+            { "AC", "Insla d\u2019Ascensiun" },
             { "rar", "rarotonga" },
             { "tet", "tetum" },
             { "AD", "Andorra" },
@@ -124,6 +126,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "nl_BE", "flam" },
             { "AF", "Afghanistan" },
             { "AG", "Antigua e Barbuda" },
+            { "type.ca.ethiopic", "chalender etiopic" },
             { "AI", "Anguilla" },
             { "AL", "Albania" },
             { "AM", "Armenia" },
@@ -158,17 +161,21 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "myv", "erzya" },
             { "BN", "Brunei" },
             { "BO", "Bolivia" },
+            { "BQ", "Antillas Ollandaisas" },
             { "BR", "Brasilia" },
             { "BS", "Bahamas" },
+            { "xog", "soga" },
             { "BT", "Bhutan" },
             { "BV", "Insla Bouvet" },
             { "BW", "Botswana" },
             { "BY", "Bielorussia" },
             { "BZ", "Belize" },
             { "Visp", "alfabet visibel" },
+            { "type.ca.persian", "chalender persian" },
             { "CA", "Canada" },
             { "CC", "Inslas Cocos" },
-            { "CD", "Republica Democratica dal Congo" },
+            { "mzn", "mazanderani" },
+            { "CD", "Congo - Kinshasa" },
             { "CF", "Republica Centralafricana" },
             { "CG", "Congo" },
             { "CH", "Svizra" },
@@ -179,16 +186,21 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "CM", "Camerun" },
             { "CN", "China" },
             { "CO", "Columbia" },
+            { "CP", "Insla da Clipperton" },
             { "CR", "Costa Rica" },
             { "CU", "Cuba" },
             { "CV", "Cap Verd" },
-            { "CX", "Insla da Christmas" },
+            { "CW", "Cura\u00e7ao" },
+            { "CX", "Insla da Nadal" },
             { "CY", "Cipra" },
-            { "CZ", "Republica Tscheca" },
+            { "CZ", "Tschechia" },
             { "eka", "ekajuk" },
+            { "Ahom", "ahom" },
             { "DE", "Germania" },
             { "goh", "vegl tudestg da scrittira" },
             { "ace", "aceh" },
+            { "cgg", "chiga" },
+            { "DG", "Diego Garcia" },
             { "DJ", "Dschibuti" },
             { "DK", "Danemarc" },
             { "ach", "acoli" },
@@ -205,6 +217,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "DZ", "Algeria" },
             { "pag", "pangasinan" },
             { "pal", "pahlavi" },
+            { "EA", "Ceuta e Melilla" },
             { "chb", "chibcha" },
             { "pam", "pampanga" },
             { "EC", "Ecuador" },
@@ -225,9 +238,10 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "ER", "Eritrea" },
             { "ES", "Spagna" },
             { "ET", "Etiopia" },
-            { "EU", "Uniun europeica" },
+            { "EU", "Uniun Europeica" },
             { "elx", "elamitic" },
             { "type.ca.gregorian", "chalender gregorian" },
+            { "EZ", "zona da l\u2019euro" },
             { "chy", "cheyenne" },
             { "Inds", "indus" },
             { "ady", "adygai" },
@@ -245,6 +259,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "GA", "Gabun" },
             { "vot", "votic" },
             { "GB", "Reginavel Un\u00ec" },
+            { "pcm", "pidgin nigerian" },
             { "GD", "Grenada" },
             { "GE", "Georgia" },
             { "GF", "Guyana Franzosa" },
@@ -268,6 +283,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "tlh", "klingonic" },
             { "Talu", "tai lue" },
             { "GY", "Guyana" },
+            { "ckb", "curd central" },
             { "zxx", "nagins cuntegns linguistics" },
             { "de_AT", "tudestg austriac" },
             { "HK", "Regiun d\u2019administraziun speziala da Hongkong, China" },
@@ -275,14 +291,17 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "HM", "Inslas da Heard e da McDonald" },
             { "HN", "Honduras" },
             { "HR", "Croazia" },
+            { "agq", "aghem" },
             { "gsw", "tudestg svizzer" },
             { "HT", "Haiti" },
             { "HU", "Ungaria" },
             { "tmh", "tamasheq" },
+            { "IC", "Inslas Canarias" },
             { "peo", metaValue_peo },
             { "ID", "Indonesia" },
             { "IE", "Irlanda" },
             { "nap", "neapolitan" },
+            { "naq", "nama" },
             { "zza", "zaza" },
             { "IL", "Israel" },
             { "IM", "Insla da Man" },
@@ -302,12 +321,14 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "JP", "Giapun" },
             { "%%1606NICT", "franzos mesaun tardiv (fin 1606)" },
             { "ain", "ainu" },
+            { "guz", "gusii" },
             { "tog", "lingua tsonga" },
             { "Kali", "kayah li" },
+            { "de_CH", "tudestg da scrittira svizzer" },
             { "type.ca.buddhist", "chalender budistic" },
             { "KE", "Kenia" },
             { "419", "America Latina" },
-            { "KG", "Kirghisistan" },
+            { "KG", "Kirgisistan" },
             { "KH", "Cambodscha" },
             { "KI", "Kiribati" },
             { "KM", "Comoras" },
@@ -344,7 +365,9 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "Kana", "katakana" },
             { "LY", "Libia" },
             { "lad", "ladino" },
+            { "vun", "vunjo" },
             { "lah", "lahnda" },
+            { "lag", "langi" },
             { "Thaa", "thaana" },
             { "MA", "Maroc" },
             { "MC", "Monaco" },
@@ -356,8 +379,9 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "Thai", metaValue_th },
             { "MH", "Inslas da Marshall" },
             { "ale", "aleutic" },
+            { "MK", "Macedonia dal Nord" },
             { "ML", "Mali" },
-            { "MM", "Myanmar" },
+            { "MM", "Myanmar (Burma)" },
             { "MN", "Mongolia" },
             { "new", "newari" },
             { "MO", "Regiun d\u2019administraziun speziala Macao, China" },
@@ -376,6 +400,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "MZ", "Mosambic" },
             { "Phli", "pahlavi dad inscripziuns" },
             { "NA", "Namibia" },
+            { "202", "Africa Subsaharica" },
             { "type.ca.hebrew", "chalender ebraic" },
             { "NC", "Nova Caledonia" },
             { "NE", "Niger" },
@@ -390,6 +415,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "NR", "Nauru" },
             { "Phnx", metaValue_phn },
             { "NU", "Niue" },
+            { "rof", "rombo" },
             { "tsi", "tsimshian" },
             { "NZ", "Nova Zelanda" },
             { "rom", "romani" },
@@ -447,7 +473,8 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "SA", "Arabia Saudita" },
             { "pon", "ponapean" },
             { "Mand", "mandaic" },
-            { "SB", "Salomonas" },
+            { "SB", "Inslas Salomonas" },
+            { "twq", "tasawaq" },
             { "011", "Africa dal Vest" },
             { "SC", "Seychellas" },
             { "SD", "Sudan" },
@@ -458,11 +485,12 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "015", "Africa dal Nord" },
             { "SG", "Singapur" },
             { "SH", "Sontg\u2019Elena" },
+            { "type.lb.strict", "stil da sigl da lingia strict" },
             { "017", "Africa Centrala" },
             { "SI", "Slovenia" },
             { "018", "Africa Meridiunala" },
             { "SJ", "Svalbard e Jan Mayen" },
-            { "019", "America dal Nord, America Centrala ed America dal Sid" },
+            { "019", "americas" },
             { "SK", "Slovachia" },
             { "SL", "Sierra Leone" },
             { "SM", "San Marino" },
@@ -471,14 +499,21 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "arn", "araucanic" },
             { "arp", "arapaho" },
             { "SR", "Surinam" },
-            { "ST", "S\u00e3o Tom\u00e9 e Principe" },
+            { "SS", "Sudan dal Sid" },
+            { "ST", "S\u00e3o Tom\u00e9 & Pr\u00edncipe" },
             { "SV", "El Salvador" },
+            { "SX", "Sint Maarten" },
             { "SY", "Siria" },
             { "yao", "yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "arawak" },
             { "yap", "yapais" },
+            { "TA", "Tristan da Cunha" },
+            { "asa", "asu" },
+            { "type.ms.ussystem", "sistem da mesira US" },
+            { "021", "Amercia dal Nord" },
             { "TC", "Inslas Turks e Caicos" },
+            { "yav", "yangben" },
             { "TD", "Tschad" },
             { "TF", "Territoris Franzos Meridiunals" },
             { "TG", "Togo" },
@@ -498,7 +533,8 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "ast", "asturian" },
             { "Orkh", "orkhon" },
             { "TZ", "Tansania" },
-            { "Zzzz", "scrittira nunenconuschenta u nunvalaivla" },
+            { "nmg", "kwasio" },
+            { "Zzzz", "scrittira nunenconuschenta" },
             { "UA", "Ucraina" },
             { "rup", "aromunic" },
             { "030", "Asia da l\u2019Ost" },
@@ -510,13 +546,17 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "type.co.pinyin", "Pinyin" },
             { "039", "Europa dal Sid" },
             { "Sinh", metaValue_si },
-            { "UM", "Inslas pitschnas perifericas dals Stadis Unids da l\u2019America" },
+            { "UM", "Inslas Pitschnas Perifericas dals Stadis Unids da l\u2019America" },
+            { "UN", "Naziuns Unidas" },
             { "US", "Stadis Unids da l\u2019America" },
             { "haw", "hawaian" },
             { "type.co.gb2312han", "chinaisa simplifitgada - GB2312" },
             { "UY", "Uruguay" },
+            { "prg", "prussian" },
             { "UZ", "Usbekistan" },
+            { "tzm", "tamazight" },
             { "type.co.stroke", "urden dals stritgs" },
+            { "nnh", "ngienboon" },
             { "VA", "Citad dal Vatican" },
             { "pro", "provenzal vegl" },
             { "VC", "Saint Vincent e las Grenadinas" },
@@ -526,46 +566,61 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "VN", "Vietnam" },
             { "VU", "Vanuatu" },
             { "nog", "nogai" },
+            { "rwk", "rwa" },
             { "non", "nordic vegl" },
             { "053", "Australia e Nova Zelanda" },
             { "%%AREVMDA", "armen occidental" },
             { "054", "Melanesia" },
-            { "WF", "Wallis e Futuna" },
+            { "WF", "Wallis & Futuna" },
             { "type.co.traditional", "reglas tradiziunalas" },
             { "057", "Regiun Micronesica" },
+            { "jgo", "ngomba" },
+            { "lkt", "lakota" },
+            { "wae", "gualser" },
             { "WS", "Samoa" },
             { "wal", "walamo" },
             { "was", "washo" },
+            { "XA", "accents pseudo" },
             { "war", "waray" },
+            { "XB", "pseudo-bidirecziunal" },
             { "awa", "awadhi" },
             { "061", "Polinesia" },
+            { "XK", "Cosovo" },
             { "Gujr", metaValue_gu },
-            { "Zxxx", "linguas na scrittas" },
+            { "Zxxx", "betg scrit" },
             { "Olck", "ol chiki" },
             { "Batk", "batak" },
             { "Blis", metaValue_zbl },
             { "YE", "Jemen" },
             { "nqo", metaValue_nqo },
+            { "type.co.standard", "zavrada da standard" },
             { "fan", "fang" },
             { "%%ROZAJ", "dialect da Resia" },
             { "fat", "fanti" },
             { "Sgnw", "lingua da segns" },
             { "YT", "Mayotte" },
             { "ZA", "Africa dal Sid" },
+            { "type.lb.loose", "stil da sigl da lingia liber" },
             { "Deva", "devanagari" },
             { "Hira", "hiragana" },
             { "ZM", "Sambia" },
             { "ZW", "Simbabwe" },
-            { "ZZ", "Regiun betg encouschenta u nunvalaivla" },
+            { "ZZ", "regiun nunenconuschenta" },
             { "Runr", "runic" },
+            { "type.ms.metric", "sistem metric" },
+            { "type.ca.iso8601", "chalender tenor ISO 8601" },
             { "lol", "lomongo" },
             { "nso", "sotho dal nord" },
             { "loz", "lozi" },
+            { "jmc", "machame" },
             { "hil", "hiligaynon" },
+            { "nus", "nuer" },
             { "dak", "dakota" },
             { "hit", "ettitic" },
             { "dar", "dargwa" },
+            { "dav", "taita" },
             { "Maya", "ieroglifas maya" },
+            { "lrc", "luri dal nord" },
             { "Copt", metaValue_cop },
             { "nwc", "newari classic" },
             { "udm", "udmurt" },
@@ -574,13 +629,16 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "sad", "sandawe" },
             { "sah", "jakut" },
             { "sam", "arameic samaritan" },
+            { "Aghb", "albanais dal Caucasus" },
             { "%%SCOUSE", "dialect scouse" },
+            { "saq", "samburu" },
             { "sas", "sasak" },
             { "sat", "santali" },
             { "Tfng", "tifinagh" },
             { "jpr", "giudaic-persian" },
             { "Guru", "gurmukhi" },
             { "lua", "luba-lulua" },
+            { "sbp", "sangu" },
             { "lui", "luiseno" },
             { "nyn", "nyankole" },
             { "nym", "nyamwezi" },
@@ -595,9 +653,10 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "den", "slavey" },
             { "ban", metaValue_ban },
             { "uga", metaValue_uga },
+            { "luy", "luyia" },
             { "bas", "basaa" },
             { "jrb", "giudaic-arab" },
-            { "es_ES", "spagnol iberic" },
+            { "es_ES", "spagnol europeic" },
             { "nzi", "nzima" },
             { "sco", "scot" },
             { "scn", "sicilian" },
@@ -612,7 +671,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "%%SOLBA", "dialect da Stolvizza" },
             { "Jpan", metaValue_ja },
             { "ar", metaValue_ar },
-            { "Hrkt", "katanaka u hiragana" },
+            { "Hrkt", "scrittira da silbas giapunaisa" },
             { "as", "assami" },
             { "Lina", "linear A" },
             { "av", "avaric" },
@@ -631,9 +690,11 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "br", "breton" },
             { "bs", "bosniac" },
             { "Mymr", "burmais" },
+            { "seh", "sena" },
             { "Nkoo", metaValue_nqo },
             { "sel", "selkup" },
             { "ca", "catalan" },
+            { "ses", "koyraboro senni" },
             { "ce", "tschetschen" },
             { "ch", "chamorro" },
             { "%%REVISED", "ortografia revedida" },
@@ -646,8 +707,9 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "cy", "kimric" },
             { "Yiii", "yi" },
             { "da", "danais" },
-            { "pt_PT", "portugais iberian" },
+            { "pt_PT", "portugais europeic" },
             { "de", "tudestg" },
+            { "type.cf.standard", "format da valuta da standard" },
             { "bej", "bedscha" },
             { "din", "dinka" },
             { "Bugi", "buginais" },
@@ -656,8 +718,11 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "dv", "maledivic" },
             { "es_419", "spagnol latinamerican" },
             { "dz", "dzongkha" },
+            { "bez", "bena" },
             { "type.ca.chinese", "chalender chinais" },
+            { "dje", "zarma" },
             { "ee", "ewe" },
+            { "type.lb.normal", "stil da sigl da lingia normal" },
             { "ro_MD", "moldav" },
             { "el", metaValue_el },
             { "en", "englais" },
@@ -665,22 +730,26 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "type.co.big5han", "chinaisa tradiziunala - Big5" },
             { "es", "spagnol" },
             { "et", "eston" },
+            { "Hanb", "han cun bopomofo" },
             { "eu", "basc" },
             { "Buhd", "buhid" },
             { "Hang", "hangul" },
             { "Samr", "samaritan" },
+            { "shi", "tachelit" },
             { "hsb", "aut sorb" },
             { "Hani", "han" },
             { "shn", "shan" },
             { "Hano", "hanunoo" },
             { "fa", "persian" },
-            { "Hans", "scrittira chinaisa simplifitgada" },
-            { "Hant", "scrittira chinaisa tradiziunala" },
+            { "Hans", "simplifitg\u00e0" },
+            { "type.nu.latn", "cifras occidentalas" },
+            { "Hant", "tradiziunal" },
             { "ff", "fulah" },
             { "fi", "finlandais" },
             { "fj", "fidschian" },
             { "fon", "fon" },
-            { "fo", "ferrais" },
+            { "yue", "cantonais" },
+            { "fo", "feroais" },
             { "umb", "mbundu" },
             { "fr", "franzos" },
             { "sid", "sidamo" },
@@ -690,7 +759,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "gl", "galician" },
             { "gn", "guarani" },
             { "bho", "bhojpuri" },
-            { "und", "linguas betg determinadas" },
+            { "und", "lingua nunenconuschenta" },
             { "gu", metaValue_gu },
             { "gv", "manx" },
             { "ha", "haussa" },
@@ -701,12 +770,13 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "bin", "bini" },
             { "ho", "hiri motu" },
             { "hr", "croat" },
-            { "ht", "haitian" },
+            { "ht", "creol haitian" },
             { "hu", "ungarais" },
             { "hy", metaValue_hy },
             { "hz", "herero" },
             { "%%FONIPA", "alfabet fonetic internaziunal (IPA)" },
             { "ia", "interlingua" },
+            { "Jamo", "jamo" },
             { "id", "indonais" },
             { "ie", "interlingue" },
             { "ig", "igbo" },
@@ -722,6 +792,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "iu", "inuktitut" },
             { "ja", metaValue_ja },
             { "Mlym", "malaisian" },
+            { "Sarb", "arab vegl dal sid" },
             { "Sara", "sarati" },
             { "doi", "dogri" },
             { "sma", "sami dal sid" },
@@ -766,12 +837,14 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "ln", "lingala" },
             { "fur", "friulan" },
             { "lo", metaValue_lo },
+            { "type.ms.uksystem", "sistem da mesira imperial" },
             { "lt", "lituan" },
             { "lu", "luba-katanga" },
             { "lv", "letton" },
             { "sog", "sogdian" },
             { "mg", "malagassi" },
             { "mh", "marschallais" },
+            { "type.co.ducet", "zavrada unicode standard" },
             { "mi", "maori" },
             { "mk", "macedon" },
             { "ml", "malayalam" },
@@ -786,6 +859,7 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "dsb", "bass sorb" },
             { "Armi", "arameic imperial" },
             { "na", "nauru" },
+            { "type.co.search", "tschertga generala" },
             { "nb", "norvegais bokm\u00e5l" },
             { "nd", "ndebele dal nord" },
             { "ne", "nepalais" },
@@ -806,11 +880,13 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "kam", "kamba" },
             { "men", "mende" },
             { "oj", "ojibwa" },
+            { "mer", "meru" },
             { "om", "oromo" },
             { "kaw", "kawi" },
             { "or", metaValue_or },
             { "os", "ossetic" },
             { "kbd", "kabardic" },
+            { "mfe", "morisyen" },
             { "srn", "sranan tongo" },
             { "pa", "punjabi" },
             { "dua", "duala" },
@@ -819,27 +895,38 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "pi", "pali" },
             { "pl", "polac" },
             { "dum", "ollandais mesaun" },
+            { "type.ca.dangi", "chalender dangi" },
             { "ps", "paschto" },
             { "pt", "portugais" },
             { "mga", "irlandais mesaun" },
             { "key.co", "zavrada" },
             { "pt_BR", "portugais brasilian" },
             { "kcg", "tyap" },
+            { "mgh", "makhuwa-meetto" },
+            { "key.cf", "format da valuta" },
             { "bra", "braj" },
             { "key.ca", "chalender" },
             { "Laoo", metaValue_lo },
+            { "mgo", "meta\u2019" },
+            { "type.hc.h23", "sistem da 24 uras (0\u201323)" },
+            { "type.hc.h24", "sistem da 24 uras (1\u201324)" },
             { "qu", "quechua" },
             { "zap", "zapotec" },
+            { "brx", "bodo" },
             { "Lana", "lanna" },
+            { "kde", "makonde" },
             { "Ethi", "etiopic" },
+            { "type.hc.h12", "sistem da 12 uras (1\u201312)" },
+            { "type.hc.h11", "sistem da 12 uras (0\u201311)" },
             { "rm", "rumantsch" },
             { "rn", "rundi" },
-            { "key.cu", "munaida" },
+            { "key.cu", "valuta" },
             { "ro", "rumen" },
             { "%%SAAHO", "Saho" },
             { "ru", "russ" },
             { "zbl", metaValue_zbl },
             { "rw", "kinyarwanda" },
+            { "kea", "cabverdian" },
             { "mic", "micmac" },
             { "suk", "sukuma" },
             { "en_AU", "englais australian" },
@@ -858,9 +945,11 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "sm", "samoan" },
             { "sn", "shona" },
             { "so", "somali" },
+            { "type.nu.arab", "cifras indic-arabas" },
             { "sq", "albanais" },
             { "sr", "serb" },
             { "ss", "swazi" },
+            { "type.cf.account", "format da valuta per la contabilitad" },
             { "Java", metaValue_jv },
             { "st", "sotho dal sid" },
             { "su", metaValue_su },
@@ -884,9 +973,10 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "tl", metaValue_tl },
             { "tn", "tswana" },
             { "to", "tonga" },
+            { "dyo", "jola-fonyi" },
             { "tr", "tirc" },
+            { "Cakm", metaValue_ccp },
             { "ts", "tsonga" },
-            { "Cakm", "chakma" },
             { "tt", "tatar" },
             { "dyu", "diula" },
             { "tw", "twi" },
@@ -910,9 +1000,11 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "%%1996", "nova ortografia tudestga" },
             { "Sylo", "syloti nagri" },
             { "ve", "venda" },
-            { "type.ca.roc", "chalendar da la republica chinaisa" },
+            { "type.ca.roc", "chalender da la Republica Chinaisa" },
             { "vi", "vietnamais" },
             { "kho", "khotanais" },
+            { "khq", "koyra chiini" },
+            { "key.hc", "ciclus da las uras" },
             { "%%TARASK", "ortografia taraskievica" },
             { "vo", "volapuk" },
             { "syc", "siric classic" },
@@ -924,6 +1016,8 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "Lydi", "lidic" },
             { "Xsux", "scrittira a cugn sumeric-accadica" },
             { "wo", "wolof" },
+            { "zgh", "marocan tamazight standardis\u00e0" },
+            { "ar_001", "arab modern standardis\u00e0" },
             { "Cans", "simbols autoctons canadais unifitgads" },
             { "gay", "gayo" },
             { "Mong", metaValue_mn },
@@ -939,32 +1033,39 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "osa", "osage" },
             { "Moon", "moon" },
             { "moh", "mohawk" },
+            { "kkj", "kako" },
             { "%%1694ACAD", "franzos modern tempriv (a partir da 1694)" },
             { "Syrc", metaValue_syr },
             { "yi", "jiddic" },
             { "mos", "mossi" },
             { "Dsrt", "deseret" },
             { "yo", "yoruba" },
+            { "es_MX", "spagnol mexican" },
             { "Syrj", "siric dal vest" },
             { "ota", "tirc ottoman" },
             { "Syre", "siric estrangelo" },
             { "vai", "vai" },
             { "za", "zhuang" },
             { "Cari", "carian" },
+            { "kln", "kalenjin" },
             { "zh", "chinais" },
             { "Bopo", "bopomofo" },
             { "Perm", "permic vegl" },
+            { "key.lb", "stil da sigl da lingia" },
             { "zu", "zulu" },
             { "type.co.phonebook", "cudesch da telefon" },
             { "%%MONOTON", "monotonic" },
             { "Geor", metaValue_ka },
+            { "Shrd", "sharada" },
             { "kmb", "kimbundu" },
             { "Cham", "cham" },
             { "gez", "geez" },
             { "Syrn", "siric da l\u2019ost" },
+            { "Narb", "arab vegl dal nord" },
             { "Tglg", metaValue_tl },
             { "Egyd", "egipzian demotic" },
             { "Egyh", "egipzian ieratic" },
+            { "ebu", "embu" },
             { "Egyp", "ieroglifas egipzianas" },
             { "Geok", "kutsuri" },
             { "zh_Hans", "chinais simplifitg\u00e0" },
@@ -979,8 +1080,10 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "%%VALENCIA", "valencian" },
             { "Cprt", "cipriot" },
             { "%%BAKU1926", "alfabet tirc unifitg\u00e0" },
+            { "mua", "mundang" },
             { "mul", "pluriling" },
             { "cad", "caddo" },
+            { "key.ms", "sistem da mesira" },
             { "mus", "creek" },
             { "Glag", "glagolitic" },
             { "gil", "gilbertais" },
@@ -988,10 +1091,13 @@ public class LocaleNames_rm extends OpenListResourceBundle {
             { "car", "caribic" },
             { "krc", "karachay-balkar" },
             { "inh", "ingush" },
+            { "fa_AF", "dari" },
             { "krl", "carelian" },
             { "efi", "efik" },
             { "kru", "kurukh" },
+            { "ksb", "shambala" },
             { "Telu", metaValue_te },
+            { "ksf", "bafia" },
         };
         return data;
     }
