@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,11 +66,11 @@ import sun.util.resources.OpenListResourceBundle;
 public class LocaleNames_so extends OpenListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String metaValue_BD = "Bangladesh";
         final String metaValue_CA = "Kanada";
         final String metaValue_DE = "Jarmal";
         final String metaValue_ET = "Itoobiya";
         final String metaValue_FR = "Faransiis";
+        final String metaValue_GE = "Joorjiya";
         final String metaValue_IT = "Talyaani";
         final String metaValue_RU = "Ruush";
         final String metaValue_ar = "Carabi";
@@ -104,7 +100,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "%%BARLA", "lahjada kooxda Barlavento ee kabuverdianu" },
             { "type.nu.sinh", "Godadka Sinhala Lith" },
             { "AD", "Andora" },
-            { "AE", "Imaaraadka Carabta ee Midoobay" },
+            { "AE", "Midawga Imaaraatka Carabta" },
             { "nl_BE", "Af faleemi" },
             { "AF", "Afgaanistaan" },
             { "AG", "Antigua & Barbuuda" },
@@ -127,7 +123,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "BA", "Boosniya & Harsegofina" },
             { "BB", "Baarbadoos" },
             { "ceb", "Sebuano" },
-            { "BD", metaValue_BD },
+            { "BD", "Bangaladhesh" },
             { "BE", "Biljam" },
             { "Sogo", "Sogdiyaankii Hore" },
             { "BF", "Burkiina Faaso" },
@@ -137,7 +133,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "BJ", "Biniin" },
             { "BL", "St. Baathelemiy" },
             { "BM", "Barmuuda" },
-            { "BN", "Buruneeya" },
+            { "BN", "Buruneey" },
             { "BO", "Boliifiya" },
             { "BQ", "Karibiyaan Nadarlands" },
             { "BR", "Baraasiil" },
@@ -166,7 +162,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "CN", "Shiinaha" },
             { "CO", "Koloombiya" },
             { "CP", "Jasiiradda Kilibarton" },
-            { "CR", "Kosta Riika" },
+            { "CR", "Costa Rica" },
             { "CU", "Kuuba" },
             { "CV", "Jasiiradda Kayb Faarde" },
             { "CW", "Kurakaaw" },
@@ -213,13 +209,13 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Taml", "Taamiil" },
             { "FR", metaValue_FR },
             { "%%SIMPLE", "Fudud" },
-            { "root", "Xidid" },
             { "%%DAJNKO", "alfabeetka Dajnko" },
-            { "type.ca.indian", "Taariikhda Qaranka Hindiya" },
+            { "type.ca.indian", "Habeentiris Qarameedka Hindiya" },
             { "GA", "Gaaboon" },
             { "GB", "Boqortooyada Midowday" },
+            { "pcm", "Bidjinka Nayjeeriya" },
             { "GD", "Giriinaada" },
-            { "GE", "Joorjiya" },
+            { "GE", metaValue_GE },
             { "GF", "Faransiis Gini" },
             { "GG", "Guurnsey" },
             { "GH", "Gaana" },
@@ -236,10 +232,12 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "GU", "Guaam" },
             { "type.nu.mathmono", "Godad Xisaabeedka Monospace" },
             { "GW", "Gini-Bisaaw" },
+            { "rhg", "Rohingya" },
             { "Talu", "Tai Lue cusub" },
             { "GY", "Guyana" },
             { "ckb", "Bartamaha Kurdish" },
             { "zxx", "Luuqad Looma Hayo" },
+            { "de_AT", "Jarmal Awsteeriya" },
             { "HK", "Hong Kong" },
             { "Vaii", "Dadka Vai" },
             { "HM", "Jasiiradda Haad & MakDonald" },
@@ -287,7 +285,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "type.nu.knda", "Godadka Kanada" },
             { "Kali", "Kayah LI" },
             { "Sidd", "Siddham" },
-            { "de_CH", "Jarmal (Iswiiserlaand)" },
+            { "de_CH", "Iswiiska Sare ee Jarmal" },
             { "type.ca.buddhist", "Habeentiriska Buudhist" },
             { "KE", "Kenya" },
             { "419", "Laatiin Ameerika" },
@@ -296,7 +294,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "KI", "Kiribati" },
             { "KM", "Komooros" },
             { "Knda", metaValue_CA },
-            { "KN", "St. Kitts & Nefis" },
+            { "KN", "St. Kitts iyo Nevis" },
             { "Zinh", "Dhaxlay" },
             { "fr_CA", "Faransiiska Kanada" },
             { "KP", "Kuuriyada Waqooyi" },
@@ -340,7 +338,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "MK", "Masedooniya Waqooyi" },
             { "type.nu.mathdbl", "Godad Xisaabeedka Labalaabma" },
             { "ML", "Maali" },
-            { "MM", "Miyanmar" },
+            { "MM", "Mayanmar" },
             { "MN", "Mongooliya" },
             { "MO", "Makaaw" },
             { "MP", "Jasiiradda Waqooyiga Mariaana" },
@@ -350,11 +348,11 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Chrs", "Luuqada Korasmiyaanka" },
             { "MT", "Maalta" },
             { "MU", "Mawrishiyaas" },
-            { "MV", "Maaldiqeen" },
+            { "MV", "Maaldiifis" },
             { "MW", "Malaawi" },
             { "MX", "Meksiko" },
             { "type.ca.japanese", "Habeentiriska jabbaanka" },
-            { "MY", "Malaysia" },
+            { "MY", "Malaysiya" },
             { "MZ", "Musambiik" },
             { "Phli", "Qoraaladii hore ee Pahlavi" },
             { "NA", "Namiibiya" },
@@ -389,16 +387,16 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "en_GB", "Ingiriis Biritish" },
             { "PE", "Beeru" },
             { "PF", "Booliyneesiya Faransiiska" },
-            { "PG", "Babua Niyuu Gini" },
+            { "PG", "Babwa Niyuu Gini" },
             { "PH", "Filibiin" },
             { "PK", "Bakistaan" },
             { "%%NICARD", "KAARKANI" },
             { "PL", "Booland" },
             { "ewo", "Eewondho" },
-            { "PM", "Saint Pierre and Miquelon" },
+            { "PM", "St. Pierre iyo Miquelon" },
             { "PN", "Bitkairn" },
             { "PR", "Bueerto Riiko" },
-            { "PS", "Falastiin Daanka galbeed iyo Qasa" },
+            { "PS", "Dhulka Falastiiniyiinta daanta galbeed iyo marinka qasa" },
             { "Bali", "Baliniis" },
             { "PT", "Bortugaal" },
             { "PW", "Balaaw" },
@@ -442,7 +440,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "014", "Afrikada Bari" },
             { "015", "Waqooyiga Afrika" },
             { "SG", "Singaboor" },
-            { "SH", "Saint Helena" },
+            { "SH", "Saynt Helena" },
             { "type.lb.strict", "Habka Jabinta Xariiqda Adag" },
             { "017", "Afrikada Dhexe" },
             { "SI", "Islofeeniya" },
@@ -511,7 +509,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "type.co.gb2312han", "Isku hagaajinta Farta shiineeska" },
             { "UY", "Uruguwaay" },
             { "prg", "Brashiyaanki Hore" },
-            { "UZ", "Uusbakistaan" },
+            { "UZ", "Usbakistan" },
             { "tzm", "Bartamaha Atlaas Tamasayt" },
             { "type.co.stroke", "Isku hagaajinta Farta" },
             { "nnh", "Ingiyembuun" },
@@ -537,7 +535,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "WS", "Samoowa" },
             { "Bass", "Qoraalka Vah" },
             { "type.nu.mtei", "Godadka Meetei Mayek" },
-            { "XA", "Shigshiga" },
+            { "XA", "Lahjadaha Pseudo" },
             { "XB", "Pseudo-Bidi" },
             { "061", "Booliyneesiya" },
             { "%%KSCOR", "heerka orthographyga" },
@@ -564,7 +562,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Hira", "Hiragana" },
             { "ZM", "Saambiya" },
             { "ZW", "Simbaabwe" },
-            { "ZZ", "Gobol aan la aqoonin amase aan saxnayn" },
+            { "ZZ", "Gobol aan la aqoonin" },
             { "Runr", "Dadka Rejang" },
             { "type.ms.metric", "Nidaamka Metric" },
             { "type.ca.iso8601", "Habeentiriska ISO-8601" },
@@ -576,7 +574,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "nus", "Nuweer" },
             { "type.nu.fullwide", "Ballac Godadka Buuxa" },
             { "dav", "Taiita" },
-            { "lrc", "Koonfurta Luuri" },
+            { "lrc", "Luri Waqooyi" },
             { "type.co.emoji", "Isku hagaajinta Emojiga" },
             { "Copt", "Dadka Kotiga" },
             { "Khmr", "Khamer" },
@@ -588,6 +586,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Aghb", "Qoraalka Luuqada Caucasian Albanian" },
             { "%%SCOUSE", "GARAACID" },
             { "saq", "Sambuuru" },
+            { "sat", "Santali" },
             { "Tfng", "Farta Tifinagh" },
             { "Guru", "Luuqada gujarati" },
             { "%%ALUKU", "Lahjada Aluku" },
@@ -596,10 +595,10 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "sbp", "Sangu" },
             { "nyn", "Inyankoole" },
             { "luo", "Luwada" },
-            { "fil", "Tagalog" },
+            { "fil", "Filibiino" },
             { "hmn", "Hamong" },
             { "type.nu.wara", "Godadka Warang Citi" },
-            { "luy", "Luhya" },
+            { "luy", "Luyia" },
             { "bas", "Basaa" },
             { "%%ABL1943", "Qaacideeynta orthographygii 1943" },
             { "es_ES", "Isbaanish (Isbayn)" },
@@ -625,7 +624,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "bg", "Bulgeeriyaan" },
             { "type.nu.java", "Godadka Javanese" },
             { "bm", "Bambaara" },
-            { "bn", metaValue_BD },
+            { "bn", "Bangladesh" },
             { "bo", "Tibeetaan" },
             { "br", "Biriton" },
             { "bs", "Bosniyaan" },
@@ -666,14 +665,14 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "type.co.big5han", "Isku hagaajinta Shiineeskii Hore - Big5" },
             { "es", "Isbaanish" },
             { "et", "Istooniyaan" },
-            { "Hanb", "luuqada Han iyo Farta Mandariinka Taywaan" },
+            { "Hanb", "Han iyo Bobomofo" },
             { "eu", "Basquu" },
             { "Buhd", "Luuqada Buhid" },
             { "Hang", "Hanguul" },
             { "Samr", "Dadka Samaritan" },
             { "shi", "Shilha" },
             { "hsb", "Sorobiyaanka Sare" },
-            { "Hani", "Luuqada Han" },
+            { "Hani", "Han" },
             { "Hano", "Qoraalka Hanunoo" },
             { "fa", "Faarisi" },
             { "Hans", "La fududeeyay" },
@@ -717,6 +716,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "ja", metaValue_ja },
             { "Mlym", "Maalayalam" },
             { "Sarb", "Crabiyaankii Hore ee Wuqooyi" },
+            { "doi", "Dogri" },
             { "type.nu.lepc", "Godadka Lepcha" },
             { "jv", "Jafaaniis" },
             { "Shaw", "calaamad qoris" },
@@ -767,11 +767,12 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "dsb", "Soorbiyaanka Hoose" },
             { "Armi", "Luuqada Imperial Aramaic" },
             { "type.co.search", "Raadinta Guud" },
-            { "nb", "Noorwijiyaan Bokma" },
-            { "nd", "Indhebeele" },
+            { "nb", "Nawrijii Bokm\u00e5l" },
+            { "nd", "Indhebeele Waqooyi" },
             { "ne", "Nebaali" },
             { "nl", "Holandays" },
-            { "nn", "Nowrwejiyan (naynoroski)" },
+            { "nn", "Nawriijiga Nynorsk" },
+            { "no", "Nawriiji" },
             { "type.nu.modi", "Godadka Modi" },
             { "Osge", "Osage" },
             { "ny", "Inyaanja" },
@@ -828,7 +829,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "sa", "Sanskrit" },
             { "%%UCCOR", "orthograpghyga mideeysan" },
             { "sd", "Siindhi" },
-            { "se", "Koonfurta Saami" },
+            { "se", "Sami Waqooyi" },
             { "sg", "Sango" },
             { "si", "Sinhaleys" },
             { "sk", "Isloofaak" },
@@ -845,7 +846,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Java", "Jafaniis" },
             { "su", "Suudaaniis" },
             { "%%NEDIS", "lahjada Natisone" },
-            { "sv", "Swiidhis" },
+            { "sv", "Iswiidhish" },
             { "sw", "Sawaaxili" },
             { "type.nu.wcho", "Godadka Wancho" },
             { "type.nu.hantfin", "Nidaam Tireedkii Hore ee Dhaqaalaha Shiinaha" },
@@ -904,6 +905,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Cans", "Qoraalka Luuqada Aborajiinka ee Kanada" },
             { "Mong", "Mongooliyaan" },
             { "Hluw", "Qoraalka Anatolian Hieroglyphs" },
+            { "mni", "Maniburi" },
             { "Latn", metaValue_la },
             { "Nand", "Nandinagari" },
             { "type.nu.hans", "Nidaam Tireedka Hore La Fududeeyay ee Shiinaha" },
@@ -918,17 +920,18 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Syrc", "Lahjada Syriac" },
             { "Dsrt", "Gobalka Deseret" },
             { "yo", "Yoruuba" },
+            { "es_MX", "Isbaanishka Mexico" },
             { "vai", "Faayi" },
             { "Cari", "Luuqada kaariyaanka" },
             { "kln", "Kalenjiin" },
             { "zh", "Shiinaha Mandarin" },
-            { "Bopo", "Farta Manadariinka Taywaan" },
+            { "Bopo", "Bobomofo" },
             { "Perm", "Permic gii hore" },
             { "key.lb", "Habka Jebinta Xariiqda" },
             { "zu", "Zuulu" },
             { "type.co.phonebook", "Isku hagaajinta foonbuuga" },
             { "%%MONOTON", "MOONOTOONIK" },
-            { "Geor", "Jiyoorjoyaan" },
+            { "Geor", metaValue_GE },
             { "Shrd", "Sharada" },
             { "%%LENGADOC", "LENGADOK" },
             { "type.nu.jpanfin", "Nidaam Tireedka Dhaqaalaha Jabbaanka" },
@@ -941,7 +944,7 @@ public class LocaleNames_so extends OpenListResourceBundle {
             { "Tglg", "Luuqada Tagalog" },
             { "Yezi", "Dadka Yesiidiga" },
             { "Palm", "Palmyrene" },
-            { "ebu", "Embuu" },
+            { "ebu", "Embu" },
             { "Egyp", "Fartii hore ee Masaarida" },
             { "zh_Hans", "Shiinaha Rasmiga ah" },
             { "Hung", "Hangariyaankii Hore" },
