@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -245,7 +241,6 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "Kpel", "Ch\u1eef Kpelle" },
             { "tkl", "Ti\u1ebfng Tokelau" },
             { "grb", "Ti\u1ebfng Grebo" },
-            { "root", "Ti\u1ebfng Root" },
             { "%%DAJNKO", "B\u1ea3ng ch\u1eef c\u00e1i Dajnko" },
             { "type.ca.indian", "L\u1ecbch Qu\u1ed1c gia \u1ea4n \u0110\u1ed9" },
             { "grc", "Ti\u1ebfng Hy L\u1ea1p c\u1ed5" },
@@ -273,6 +268,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "GU", "Guam" },
             { "type.nu.mathmono", "Ch\u1eef s\u1ed1 Mathmono" },
             { "GW", "Guinea-Bissau" },
+            { "rhg", "Ti\u1ebfng Rohingya" },
             { "tli", "Ti\u1ebfng Tlingit" },
             { "tlh", "Ti\u1ebfng Klingon" },
             { "Talu", "Ch\u1eef Th\u00e1i L\u1eb7c m\u1edbi" },
@@ -280,7 +276,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "ckb", "Ti\u1ebfng Kurd Mi\u1ec1n Trung" },
             { "zxx", "Kh\u00f4ng c\u00f3 n\u1ed9i dung ng\u00f4n ng\u1eef" },
             { "Jurc", "Ch\u1eef Jurchen" },
-            { "HK", "H\u1ed3ng K\u00f4ng, Trung Qu\u1ed1c" },
+            { "HK", "\u0110\u1eb7c khu H\u00e0nh ch\u00ednh H\u1ed3ng K\u00f4ng, Trung Qu\u1ed1c" },
             { "Vaii", "Ch\u1eef Vai" },
             { "HM", "Qu\u1ea7n \u0111\u1ea3o Heard v\u00e0 McDonald" },
             { "HN", "Honduras" },
@@ -398,7 +394,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "MM", "Myanmar (Mi\u1ebfn \u0110i\u1ec7n)" },
             { "MN", "M\u00f4ng C\u1ed5" },
             { "new", "Ti\u1ebfng Newari" },
-            { "MO", "Macao, Trung Qu\u1ed1c" },
+            { "MO", "\u0110\u1eb7c khu H\u00e0nh ch\u00ednh Macao, Trung Qu\u1ed1c" },
             { "aln", "Ti\u1ebfng Gheg Albani" },
             { "MP", "Qu\u1ea7n \u0111\u1ea3o B\u1eafc Mariana" },
             { "MQ", "Martinique" },
@@ -547,7 +543,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "SX", "Sint Maarten" },
             { "SY", "Syria" },
             { "yao", "Ti\u1ebfng Yao" },
-            { "SZ", "Swaziland" },
+            { "SZ", "Eswatini" },
             { "arw", "Ti\u1ebfng Arawak" },
             { "arz", "Ti\u1ebfng \u1ea2 R\u1eadp Ai C\u1eadp" },
             { "yap", "Ti\u1ebfng Yap" },
@@ -614,7 +610,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "VC", "St. Vincent v\u00e0 Grenadines" },
             { "VE", "Venezuela" },
             { "VG", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c Anh" },
-            { "VI", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c M\u1ef9" },
+            { "VI", "Qu\u1ea7n \u0111\u1ea3o Virgin thu\u1ed9c Hoa K\u1ef3" },
             { "VN", "Vi\u1ec7t Nam" },
             { "VU", "Vanuatu" },
             { "nog", "Ti\u1ebfng Nogai" },
@@ -727,7 +723,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "nyo", "Ti\u1ebfng Nyoro" },
             { "luo", "Ti\u1ebfng Luo" },
             { "fil", "Ti\u1ebfng Philippines" },
-            { "hmn", "Ti\u1ebfng Hm\u00f4ng" },
+            { "hmn", "Ti\u1ebfng H\u2019M\u00f4ng" },
             { "del", "Ti\u1ebfng Delaware" },
             { "lus", "Ti\u1ebfng Lushai" },
             { "bal", "Ti\u1ebfng Baluchi" },
@@ -964,7 +960,7 @@ public class LocaleNames_vi extends OpenListResourceBundle {
             { "mg", "Ti\u1ebfng Malagasy" },
             { "mh", "Ti\u1ebfng Marshall" },
             { "type.co.ducet", "Th\u1ee9 t\u1ef1 s\u1eafp x\u1ebfp unicode m\u1eb7c \u0111\u1ecbnh" },
-            { "mi", "Ti\u1ebfng Maori" },
+            { "mi", "Ti\u1ebfng M\u0101ori" },
             { "mk", "Ti\u1ebfng Macedonia" },
             { "ml", "Ti\u1ebfng Malayalam" },
             { "mn", "Ti\u1ebfng M\u00f4ng C\u1ed5" },
