@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -280,7 +276,6 @@ public class LocaleNames_yue extends OpenListResourceBundle {
             { "pcd", "\u5e87\u5361\u5e95\u6587" },
             { "tkl", "\u6258\u514b\u52de\u6587" },
             { "grb", "\u683c\u5217\u535a\u6587" },
-            { "root", "\u6839\u8a9e\u8a00" },
             { "type.ca.indian", "\u5370\u5ea6\u570b\u66c6" },
             { "rgn", "\u7f85\u99ac\u683c\u8afe\u91cc\u6587" },
             { "grc", "\u53e4\u5e0c\u81d8\u6587" },
@@ -309,6 +304,7 @@ public class LocaleNames_yue extends OpenListResourceBundle {
             { "GU", "\u95dc\u5cf6" },
             { "pdc", "\u8cd3\u5915\u6cd5\u5c3c\u4e9e\u5fb7\u6587" },
             { "GW", "\u5e7e\u5167\u4e9e\u6bd4\u7d22" },
+            { "rhg", "\u7f85\u8208\u4e9e\u6587" },
             { "tli", "\u7279\u6797\u57fa\u7279\u6587" },
             { "tlh", "\u514b\u6797\u8ca2\u6587" },
             { "Talu", "\u897f\u96d9\u7248\u7d0d\u65b0\u50a3\u6587" },
