@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -290,6 +290,14 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
                "Ton\u017esk\u00fd \u010das",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukonsk\u00fd \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Alja\u0161sk\u00fd standardn\u00ed \u010das",
                "AKST",
@@ -1464,7 +1472,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1671,7 +1679,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "America/Paramaribo", Suriname },
             { "America/Rio_Branco", Acre },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1921,6 +1929,7 @@ public class TimeZoneNames_cs extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Mayotte", "Mayotte" },
             { "timezone.excity.Indian/Reunion", "R\u00e9union" },
             { "timezone.excity.Pacific/Easter", "Velikono\u010dn\u00ed ostrov" },
+            { "timezone.excity.Pacific/Kanton", "Kanton" },
             { "timezone.excity.Pacific/Kosrae", "Kosrae" },
             { "timezone.excity.Pacific/Majuro", "Majuro" },
             { "timezone.excity.Pacific/Midway", "Midway" },
