@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -274,6 +274,14 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "tongaski \u010das",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukonowy \u010das",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "alaskaski standardny \u010das",
                "",
@@ -442,6 +450,14 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "chathamski \u010das",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "koordinowany sw\u011btowy \u010das",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Ecuador = new String[] {
                "ekwadorski \u010das",
                "",
@@ -786,14 +802,6 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
                "kapverdski \u010das",
                "",
             };
-        final String[] EMPTY_ZONE = new String[] {
-               "",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] East_Timor = new String[] {
                "wuchodnotimorski \u010das",
                "",
@@ -1212,7 +1220,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC", EMPTY_ZONE },
+            { "UTC", ETC_UTC },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
             { "ART", Europe_Eastern },
@@ -1237,6 +1245,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Aden", Arabian },
@@ -1403,7 +1412,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1606,7 +1615,7 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1692,7 +1701,9 @@ public class TimeZoneNames_hsb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
+            { "timezone.excity.Asia/Karachi", "Kara\u010di" },
             { "timezone.excity.Asia/Nicosia", "Nikosia" },
+            { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
             { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
             { "timezone.excity.Asia/Yerevan", "Jerjewan" },
