@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -82,6 +82,14 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
                "Ora di Kuba",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Ora di Yukon",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Ora Padron di Alaska",
                "",
@@ -413,7 +421,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -542,7 +550,7 @@ public class TimeZoneNames_kea extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
