@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -67,7 +67,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "\u0917\u094d\u0930\u0940\u0928 \u0935\u093f\u091a\u0941 \u092e\u0940\u0928 \u091f\u093e\u0907\u092e\u0941",
+               "\u0917\u094d\u0930\u0940\u0928\u0935\u093f\u091a \u092e\u0940\u0928 \u0935\u0915\u094d\u0924\u0941",
                "",
                "",
                "",
@@ -75,7 +75,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
                "",
             };
         final String[] ETC_UTC = new String[] {
-               "\u0906\u0938\u094d\u0925\u093e\u0928\u0940 \u091a\u093e\u0932\u0942 \u091f\u093e\u0907\u092e\u0941",
+               "\u0917\u0926\u093f\u0952\u092f\u0932 \u0906\u0932\u092e\u0940 \u0935\u0915\u094d\u0924\u0941",
                "UTC",
                "",
                "",
@@ -83,67 +83,67 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
                "",
             };
         final String[] Atlantic = new String[] {
-               "\u0905\u0902\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091c\u0947 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
-               "\u0905\u0902\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091c\u0947 \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
                "",
-               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u091f\u093e\u0907\u092e\u0941",
+               "\u0905\u091f\u0932\u093e\u0902\u091f\u093f\u0915 \u0935\u0915\u094d\u0924",
                "",
             };
         final String[] Europe_Central = new String[] {
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u092e\u092f\u0906\u0930\u0940 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0938\u0947\u0902\u091f\u0930\u0932\u0941 \u092f\u0942\u0930\u092a\u0940 \u091f\u093e\u0907\u092e\u0941",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924",
                "",
             };
         final String[] Europe_Eastern = new String[] {
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u091f\u093e\u0907\u092e\u0941",
+               "\u0913\u092d\u0930\u0940 \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924\u0941",
                "",
             };
         final String[] Europe_Western = new String[] {
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u091c\u0947 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u091c\u0947 \u092f\u0942\u0930\u094b\u092a\u0940\u0905 \u0917\u0930\u092e\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0909\u0928\u0939\u093e\u0930\u0947 \u091c\u094b \u0935\u0915\u094d\u0924\u0941",
                "",
-               "\u0909\u0932\u0939\u0902\u0926\u094b \u0935\u093e\u0930\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u093e\u0930\u094b \u0935\u0915\u094d\u0924\u0941",
+               "\u0909\u0932\u0939\u0902\u0926\u094b \u092f\u0942\u0930\u094b\u092a\u0940 \u0935\u0915\u094d\u0924\u0941",
                "",
             };
         final String[] America_Central = new String[] {
-               "\u0935\u093f\u091a\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u092d\u0947\u0930\u094b",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
-               "\u0935\u093f\u091a\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
                "",
-               "\u0935\u093f\u091a\u094b \u092d\u0947\u0930\u094b",
+               "\u092e\u0930\u0915\u091c\u093c\u0940 \u0935\u0915\u094d\u0924",
                "",
             };
         final String[] America_Eastern = new String[] {
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u0913\u092d\u0930\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u0935\u093f\u091a\u094b \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u0913\u092d\u0930\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
                "",
-               "\u0909\u092d\u093f\u0930\u0902\u0926\u094b \u092d\u0947\u0930\u094b",
+               "\u0913\u092d\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
             };
         final String[] America_Pacific = new String[] {
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u0935\u093e\u0930\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u091c\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
                "",
-               "\u092a\u0947\u0938\u0940\u092b\u093f\u0915 \u0935\u093e\u0930\u094b \u091f\u093e\u0907\u092e\u0941",
+               "\u092a\u0947\u0938\u093f\u092b\u093f\u0915 \u0935\u0915\u094d\u0924",
                "",
             };
         final String[] America_Mountain = new String[] {
-               "\u091f\u0915\u0930\u0941 \u0935\u093e\u0930\u094b \u092e\u0905\u092f\u093e\u0930\u0940 \u092d\u0947\u0930\u094b",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u092e\u0905\u092f\u093e\u0930\u0940 \u0935\u0915\u094d\u0924",
                "",
-               "\u091f\u0915\u0930\u0941 \u091c\u094b \u097e\u0940\u0902\u0939 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u0926\u0940\u0902\u0952\u0939 \u091c\u094b \u0935\u0915\u094d\u0924",
                "",
-               "\u091f\u0915\u0930\u0941 \u0935\u093e\u0930\u094b \u092d\u0947\u0930\u094b",
+               "\u092a\u0939\u093e\u0921\u093c\u0940 \u0935\u0915\u094d\u0924",
                "",
             };
         final Object[][] data = new Object[][] {
@@ -221,7 +221,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Inuvik", America_Mountain },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
@@ -309,7 +308,6 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Martinique", Atlantic },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -348,7 +346,7 @@ public class TimeZoneNames_sd_Deva extends TimeZoneNamesBundle {
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Etc/Unknown", "\u092c\u0947\u0916\u092c\u0930\u094b \u0936\u0939\u0930\u0941" },
+            { "timezone.excity.Etc/Unknown", "\u0905\u0923\u091c\u093e\u0952\u0924\u0932 \u0936\u0939\u0930\u0941" },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
