@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -102,14 +98,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
                "Saa za Irani",
                "",
             };
-        final String[] India = new String[] {
-               "Saa za Wastani za India",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Japan = new String[] {
                "Saa za Wastani za Japani",
                "",
@@ -150,14 +138,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Ecuador = new String[] {
-               "Saa za Ekwado",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Georgia = new String[] {
                "Saa za Wastani za Jiojia",
                "",
@@ -246,22 +226,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
                "Saa za Ajentina",
                "",
             };
-        final String[] Christmas = new String[] {
-               "Saa za Kisiwa cha Krismasi",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
-        final String[] Macquarie = new String[] {
-               "Saa za Makwuarie",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] Singapore = new String[] {
                "Saa za Wastani za Singapoo",
                "",
@@ -426,7 +390,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             { "Asia/Atyrau", Kazakhstan_Western },
             { "Asia/Muscat", Gulf },
             { "Asia/Tehran", Iran },
-            { "Asia/Colombo", India },
             { "Asia/Karachi", Pakistan },
             { "Asia/Kuching", Malaysia },
             { "Asia/Rangoon", Myanmar },
@@ -436,7 +399,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             { "America/Belem", Brasilia },
             { "America/Jujuy", Argentina },
             { "Asia/Ashgabat", Turkmenistan },
-            { "Asia/Calcutta", India },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Katmandu", Nepal },
             { "Asia/Qostanay", Kazakhstan_Eastern },
@@ -459,12 +421,10 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             { "America/Asuncion", Paraguay },
             { "America/Santarem", Brasilia },
             { "Asia/Ulaanbaatar", Mongolia },
-            { "Indian/Christmas", Christmas },
             { "Pacific/Auckland", New_Zealand },
             { "America/Araguaina", Brasilia },
             { "America/Catamarca", Argentina },
             { "America/Fortaleza", Brasilia },
-            { "America/Guayaquil", Ecuador },
             { "America/Sao_Paulo", Brasilia },
             { "Asia/Kuala_Lumpur", Malaysia },
             { "Pacific/Enderbury", Phoenix_Islands },
@@ -474,7 +434,6 @@ public class TimeZoneNames_sw_KE extends TimeZoneNamesBundle {
             { "Atlantic/Cape_Verde", Cape_Verde },
             { "America/Buenos_Aires", Argentina },
             { "America/Santa_Isabel", Mexico_Northwest },
-            { "Antarctica/Macquarie", Macquarie },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "Antarctica/South_Pole", New_Zealand },
             { "Atlantic/South_Georgia", South_Georgia },
